#!/bin/sh

#PBS -N sttpicard
#PBS -q fnrdewoody
#PBS -l nodes=1:ppn=1,naccesspolicy=singleuser
#PBS -l walltime=300:00:00
#PBS -m abe

module load bioinfo
module load samtools
module load picard-tools

cd $PBS_O_WORKDIR

FILE=$"tergeminus" 

# validate sam file
# you need to check that the output file has NO errors
PicardCommandLine ValidateSamFile I=${FILE}.sam MODE=SUMMARY O=${FILE}_samfile.txt
PicardCommandLine SortSam SORT_ORDER=coordinate INPUT=${FILE}.sam OUTPUT=out.bam \
TMP_DIR=`pwd`/tmp VALIDATION_STRINGENCY=LENIENT


# marking PCR duplicated reads without removing them
PicardCommandLine MarkDuplicates INPUT=out.bam OUTPUT=marked.bam M=metrics.txt

# check coverage
PicardCommandLine CollectWgsMetrics I=marked.bam \
O=coverage_marked.txt R=ref.fa 

PicardCommandLine BuildBamIndex INPUT=marked.bam

# create reference that reads can be mapped to. Will produce .fai file
samtools faidx ref.fa

PicardCommandLine CreateSequenceDictionary \
reference=ref.fa output=ref.dict

# END
 