#!/bin/sh

#PBS -N combineGVCFs
#PBS -q fnrgenetics
#PBS -l nodes=1:ppn=1,naccesspolicy=singleuser
#PBS -l walltime=300:00:00
#PBS -m abe

module load bioinfo
module load GATK/3.8.1

cd $PBS_O_WORKDIR

FILE1=$"tergeminus"
FILE2=$"edwardsii"
GROUP=$"snakes"

# By hand: verified identical ref.fa.fai and ref.dict files were identical for each sample
# then: copied one of each file to working directory and changed paths in ref.dict to match working directory using GUI text replacement in winscp

cp stt/${FILE1}.g.vcf.idx .
cp stt/${FILE1}.g.vcf .
cp ste/${FILE2}.g.vcf.idx .
cp ste/${FILE2}.g.vcf .

# run GenotypeGVCF to create raw SNP and indel VCFs
java -jar $GATK -T CombineGVCFs \
-R ref.fa \
   --variant ${FILE1}.g.vcf \
   --variant ${FILE2}.g.vcf \
   -o ${GROUP}.g.vcf

mkdir tmp

# you need to set the path to your tmp in the following
# convert g.vcf to vcf
java -Djava.io.tmpdir=/scratch/snyder/b/bylsma/massasauga/drew_variants/tmp/ \
	-jar $GATK -T GenotypeGVCFs \
   -R ref.fa \
   --variant ${GROUP}.g.vcf \
   -o ${GROUP}.vcf

# select SNPs only
GenomeAnalysisTK -T SelectVariants -R ref.fa \
-V ${GROUP}.vcf -selectType SNP -o ${GROUP}_SNPs.vcf

# END

