#!/bin/sh

#PBS -N filtering
#PBS -q standby
#PBS -l nodes=1:ppn=1,naccesspolicy=singleuser
#PBS -l walltime=4:00:00
#PBS -m abe

module load bioinfo
module load GATK/3.8.1
module load samtools

cd $PBS_O_WORKDIR

VCFIN=$"snakes_SNPs"
REF=$"ref"
FILTEROUT=$"filteredSNPs_snakes"
OUT=$"passSNPs_snakes"

# STEP7: Variant Filtering (for SNPassay)
# Our SelectVariants command is a little different given that we have different goals with this round of SNP calling.  #
# We use --clusterSize 2 and --clusterWindowSize 20 because we want to ignore any SNPs that are within 20 bp of another #
# SNP (this is a requirement of Fluidigm).  Depth is correlated with SNP convergence, so we add --filterExpression "DP<10" #
# to get rid of SNPs with very low depth.  We now use "QUAL<30" since we are no longer trying to come up with a set of super high quality SNPs. #
# VariantFiltration will filter out any SNPs that #fulfill# the criteria of each --filterExpression #

GenomeAnalysisTK -T VariantFiltration -R ${REF}.fa -V ${VCFIN}.vcf \
--clusterSize 2 --clusterWindowSize 20 \
--filterName "LowVQCBD" --filterExpression "QD<5.0" \
--filterName "highSOR" --filterExpression "SOR>4.0" \
--filterName "highDP" --filterExpression "DP>100" \
--filterName "LowQual" --filterExpression "QUAL<30.0" \
--filterName "lowDP" --filterExpression "DP<10" \
-o ${FILTEROUT}.vcf 2>&1 | tee variantfiltration.log

cat ${FILTEROUT}.vcf | grep 'PASS\|^#' > ${OUT}.vcf

vcfutils.pl qstats ${OUT}.vcf > SNP_stats.txt


#END