#!/bin/sh

#PBS -N snpEff
#PBS -q standby
#PBS -l nodes=1:ppn=10,naccesspolicy=singleuser
#PBS -l walltime=4:00:00
#PBS -m abe

module load bioinfo
module load anaconda
module load snpEff/4.3

cd $PBS_O_WORKDIR

REF=$"CroVir"
VCF=$"passSNPs_snakes"
ANNVCF=$"annotatedSNPs_snakes"


#Things to do manually:

# Must copy snpEff.config from module file
cp /group/bioinfo/apps/apps/snpEff-4.3T/snpEff.config .
# Then edit to add your reference genome (See snpEff user guide "add a genome to the configuration file")
	## Added by NAME on DATE
	# reference_species_name genome, version whatever_version
	${REF}.genome : reference_assembly_name
# Make subdirectories in your working directory ./data/${REF}/ and .data/genomes/
# Copy reference genome files to ${REF} subdirectory and copy ${REF}.fa (or .fna) to genomes subdirectory
wget __NCBI_ftp_address___ ./data/${REF} # Rename files as you want for simplicity
cp ./data/${REF}/${REF}.fa ./data/genomes/.

#Script to run:

# rename ${ref}.gff to genes.gff, ${REF}.fa to sequences.fa in ${REF} directory.
cp ./data/${REF}/${REF}.gff ./data/${REF}/genes.gff
cp ./data/${REF}/${REF}.fa ./data/${REF}/sequences.fa
#convert GFF3 file to GTF #Python script from Devon Ryan, moderator at Bioinformatics StackExchange (https://bioinformatics.stackexchange.com/users/77/devon-ryan)
./gff3_to_gtf22.py ./data/${REF}/genes.gff > ./data/${REF}/genes.gtf
# submitted job in attempt to run with gff file (not recommended by snpEff) but holds more data
# then submitted second script with build command input changed ("-gff3" to "-gtf") and submitted with depend=afternotok
# this dependency allows the second script to run this weekend if the first script leaves with an error. Keeps me from wasting the weekend.
# NOTE: first script ran just fine off of -gff3 option

snpEff build -t -c snpEff.config -gff3 -v ${REF} 2>&1 | tee build.log

snpEff ann -t -c snpEff.config -no-downstream -no-intergenic -no-intron -no-upstream -no-utr -v \
${REF} ${VCF}.vcf > ${ANNVCF}.vcf

snpEff -c snpEff.config ${REF} ${ANNVCF}.vcf > countReads.txt

#END
