#!/bin/sh -l
#PBS -q debug
#PBS -l nodes=1:ppn=20,naccesspolicy=singleuser
#PBS -l walltime=00:30:00
#PBS -N neutral_filter

# run in debug because each part of script is very fast ( =<5 minutes for my files - full rattlesnake genome SNPs)

cd $PBS_O_WORKDIR

module purge
module load bioinfo
module load perl
module load bedops

# To generate distances between each SNP and its nearest genes upstream and downstream, you will need a .gff file
# (mine was called genes.gff) and your passSNPs_snakes.vcf file - generated by the the 'cat' function in 7_GATK.job script

# To prep the .gff file, first remove the trailing semicolons in the file and then remove all features that aren�t genes (e.g., mRNA, exons, etc.)
# ran manually on front end
awk '{gsub(/;$/,"");print}' ./data/CroVir/genes.gff > revised_genes.gff
cat revised_genes.gff | awk '$3 =="gene" {print $0}' > just_genes.gff


# Use bedops to measure distances between genes and SNPs:
gff2bed < just_genes.gff > just_genes.bed
vcf2bed < passSNPs_snakes.vcf > passSNPs_snakes.bed
sort-bed passSNPs_snakes.bed > sortedSNPs_snakes.bed
sort-bed just_genes.bed > sorted_just_genes.bed
closest-features --delim '\t' --dist sortedSNPs_snakes.bed sorted_just_genes.bed > distance2genes_tab.txt

# This perl script filters the neutral loci down. Check that the column numbers match appropriately to allow proper filtering of all entries. Then play with the parameters.
perl neutral_filtering.pl

sort -t$'\t' -k34 -nr distance2genesE_average_distance_genes_SNPs.txt > sorted_distance2genes_10kb_SNPs.txt

# END
