#install.packages("wesanderson")
#biocLite("LEA")

source("http://membres-timc.imag.fr/Olivier.Francois/Conversion.R")
source("http://membres-timc.imag.fr/Olivier.Francois/POPSutilities.R")
library(LEA)
library(adegenet)
#defined palette based on zhangyimou.R
display_palette("FlyingDaggers")
display_palette("RoadHome")
display_palette("OneLess")
display_palette("RedLantern")


#setwd("D:/DeWoody Lab/Massasauga Rattlesnakes/scripts and outputs/")
setwd("C:/Users/Rian/Desktop/scripts and outputs/")

# files converted genepop -> structure in PGDspider GUI
# the structure infile needs to be without the header, so no locus names

##### running structure #####

# convert: structure -> geno for snmf()
  # structure files created from genepop input files in PGDspider GUI, loci header removed
struct2geno(file = "structure_input_western.txt", TESS = T, diploid = TRUE, 
            FORMAT = 2, extra.row = 0, extra.col = 0,
            output = "snmf_input_western.geno")
struct2geno(file = "structure_input_western_neu.txt", TESS = T, diploid = TRUE, 
            FORMAT = 2, extra.row = 0, extra.col = 0,
            output = "snmf_input_western_neu.geno")
struct2geno(file = "structure_input_western_adap.txt", TESS = T, diploid = TRUE, 
            FORMAT = 2, extra.row = 0, extra.col = 0,
            output = "snmf_input_western_adap.geno")
struct2geno(file = "structure_input_western_stt.txt", TESS = T, diploid = TRUE, 
            FORMAT = 2, extra.row = 0, extra.col = 0,
            output = "snmf_input_western_stt.geno")
struct2geno(file = "structure_input_western_ste.txt", TESS = T, diploid = TRUE, 
            FORMAT = 2, extra.row = 0, extra.col = 0,
            output = "snmf_input_western_ste.geno")

# read in a table with sample, state, and county names in the same order as the snmf input
table.w.sample.names <- read.csv("Genotyping results Western.csv", header = T)
sample.order <- table.w.sample.names$Sample
state.order <- table.w.sample.names$State
stateID.order <- table.w.sample.names$IDwithState

# A regularization parameter, alpha (a), controls the regularity of ancestry 
  # estimates over the geographic space. Large values of alpha imply that 
  # ancestry coefficients have similar values for nearby individuals, 
  # whereas small values produce results close to STRUCTURE. 
  # choosing the number of clusters
  # change K to the number of populations that you want to test

# The number of ancestral gene pools (K) and the regularization parameter (a) were chosen to minimize the cross-entropy criterion.

# To choose the best alpha (a)
# Case 1: Plot all cross entropies for range of a across range of K
  # runtime was approx. 45 minutes

ce_a <- matrix(, nrow = 10, ncol = 21)
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
par(xpd = T, mar = c(3,3,3,10), mgp = c(2,1,0))
plot(0,0,type='n', xlim=c(0,21), ylim =c (0.5,0.7), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy")
#frame()
for (j in 1:10)
{
  r <- 0
  for (i in seq(from=0, to= 100, by=5))
  {
    r <- r+1
    obj.snmf = snmf("snmf_input_western.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 10)
    ce_a[,r] <- cross.entropy(obj.snmf, K = j)
    best_a[r] <- min(ce_a[,r])
  }
  #x <- c(1:101)
  #lo <- loess(best_a~x
  lines(best_a, type='l', col =pal[j], lwd=2)
}
legend(22,0.7, horiz = F,
       legend=c("k=1","k=2", "k=3","k=4","k=5","k=6","k=7","k=8","k=9","k=10"),
       lty = 1, lwd=2, col= pal[1:10], cex = 0.6, ncol = 1)
axis(side = 1, at=c(0:20),
     labels = c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100))

# Case 2: Plot mean cross entropies for series of K at series of a
ce_a <- vector()
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
plot(0,0,type='n', xlim=c(0,101), ylim =c (0.6,0.8), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy")
for (i in seq(from=0, to= 100, by=5))
{
  r <- 0
  obj.snmf = snmf("snmf_input_western.geno", K = 1:10,  ploidy = 2, entropy = T,
                  alpha = i, project = "new", repetitions = 10)
  for (j in 1:10)
  {
    r <- r+1
    ce_a[r] <- min(cross.entropy(obj.snmf, K = j))
  }
  best_a <- min(ce_a)
  points(i,best_a, type='b', col ="Red", lwd=2, pch=19)
}
axis(side = 1, at=x,
     labels = x)

# Best a = 5,30

obj.snmf = snmf("snmf_input_western.geno", K = 1:10,  ploidy = 2, entropy = T,
                alpha = 30, project = "new", repetitions = 100)

# make plot of all k
pdf(paste0("western_K_entropy_a_30.pdf"),width = 3.5, height = 3.5)
plot(obj.snmf, col = "blue4", cex = 1.2, cex.axis = 1, cex.lab = 1.2,
     cex.main = 1.2, pch = 19, type='l')
main = paste0("western_individuals")
dev.off()

# best K = 4 (5, 2, 3) ; 3 (2, 4)

## run SNMF for chosen K (k = 2 included to directly test subspecies hypothesis)
#obj.snmf.2 = snmf("snmf_input_western.geno", K = 2, alpha = 15, project = "new", repetitions = 30, entropy = T) # thirty repetitions
#ce.2 = cross.entropy(obj.snmf.2, K = 2) # extract cross-entropy values for each of thirty runs
#best.2 = which.min(ce.2) # select best of thirty runs (lowest cross-entropy)
#qmatrix2 = as.data.frame(Q(obj.snmf.2, K = 2, run = best.2)) # put admixture proportions for best run into matrix for plotting
## all thirty repetitions stored in snmf project in working directory after R session closes
#
#obj.snmf.3 = snmf("snmf_input_western.geno", K = 3, alpha = 15, project = "new", repetitions = 30, entropy = T)
#ce.3 = cross.entropy(obj.snmf.3, K = 3)
#best.3 = which.min(ce.3)
#qmatrix3 = as.data.frame(Q(obj.snmf.3, K = 3, run = best.3))
#
#obj.snmf.4 = snmf("snmf_input_western.geno", K = 4, alpha = 15, project = "new", repetitions = 30, entropy = T)
#best.4 = which.min(ce.4)
#qmatrix4 = as.data.frame(Q(obj.snmf.4, K = 4, run = best.4))
#
#obj.snmf.5 = snmf("snmf_input_western.geno", K = 5, alpha = 15, project = "new", repetitions = 30, entropy = T)
#ce.5 = cross.entropy(obj.snmf.5, K = 5)
#best.5 = which.min(ce.5)
#qmatrix5 = as.data.frame(Q(obj.snmf.5, K = 5, run = best.5))
#
## sort qmatrices for each subspecies by proportion of first ancestral population
#Q2a <- qmatrix2[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
#Q2b <- qmatrix2[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
#Q2aSort <- Q2a[order(Q2a$V1),] # sort by admixture proportion of first ancenstral population
#Q2bSort <- Q2b[order(Q2b$V1),] # same
#qmatrix2Sorted <-rbind(Q2aSort,Q2bSort) # recombine subspecies matrices into single, sorted matrix
#
#Q3a <- qmatrix3[1:44,]
#Q3b <- qmatrix3[45:78,]
#Q3aSort <- Q3a[order(Q3a$V1),]
#Q3bSort <- Q3b[order(Q3b$V1),]
#qmatrix3Sorted <-rbind(Q3aSort,Q3bSort)
#
#Q4a <- qmatrix4[1:44,]
#Q4b <- qmatrix4[45:78,]
#Q4aSort <- Q4a[order(Q4a$V1),]
#Q4bSort <- Q4b[order(Q4b$V1),]
#qmatrix4Sorted <-rbind(Q4aSort,Q4bSort)
#
#Q5a <- qmatrix5[1:44,]
#Q5b <- qmatrix5[45:78,]
#Q5aSort <- Q5a[order(Q5a$V1),]
#Q5bSort <- Q5b[order(Q5b$V1),]
#qmatrix5Sorted <-rbind(Q5aSort,Q5bSort)
#
## define color palette
#pal <- c("#FF1300", "#00D53A", "#0E18FB", "#FBF40E","#FFA200",
#         "#00FFEC", "#A600FF", "#FF00D8", "#8A5F5F", "#2A5435")
#
## Individual plots
## k = 3 plot
#pdf(paste0("western_structure_plot_k3_a15.pdf"),width = 7, height = 3.5)
#  barplot(t(qmatrix3Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, 
#          ylab = "Admixture coefficients", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#
## k = 4 plot
#pdf(paste0("western_structure_plot_k4_a15.pdf"),width = 7, height = 3.5)
#  barplot(t(qmatrix4Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, 
#          ylab = "Admixture coefficients", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#
## k = 5 plot
#pdf(paste0("western_structure_plot_k5_a15.pdf"),width = 7, height = 3.5)
#  barplot(t(qmatrix5Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, 
#          ylab = "Admixture coefficients", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#
## k = 2 plot
#pdf(paste0("western_structure_plot_k2_a15.pdf"),width = 7, height = 3.5)
#  barplot(t(qmatrix2Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, 
#          ylab = "Admixture coefficients", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#
#qmatrix2Sorted <- read.csv("neu.qmatrix.a5.k2.csv", header = T, row.names = T)
## generate Fig4.tif (LEA plot for k = 2)
#tiff("Fig4.tif", width = 900, height = 300)
#  barplot(t(qmatrix2Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, # axisnames = F to remove meaningless individual labels below barplot
#          ylab = "Admixture coefficients (k = 2)", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#
## Generate combined figure as pdf (SI figure):
#pdf(paste0("western_structure_plot_k2-5_a15.pdf"),width = 7, height = 14)
##tiff(paste0("western_structure_plot_k2-5_a15.tif"),width = 1400, height = 700)
#par(mfrow=c(2,2))
#  barplot(t(qmatrix2Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F,
#          ylab = "Admixture coefficients (k=2)", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#    mtext("Desert", side = 1, at = 22, font = 2) # group label
#    mtext("Prairie", side = 1, at = 60, font = 2) # group label
#    abline(v = 44, lwd = 2) # line dividing groups
#  barplot(t(qmatrix3Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F,
#          ylab = "Admixture coefficients (k=3)", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#  barplot(t(qmatrix4Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F,
#          ylab = "Admixture coefficients (k=4)", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#  barplot(t(qmatrix5Sorted), col = c(pal), border = NA, 
#          space = 0, xlab = "Individuals", axisnames = F, 
#          ylab = "Admixture coefficients (k=5)", cex = 1.2, cex.axis = 1, 
#          cex.lab = 1.2, cex.main = 1.2,  pch = 19)
#  mtext("Desert", side = 1, at = 22, font = 2) # group label
#  mtext("Prairie", side = 1, at = 60, font = 2) # group label
#  abline(v = 44, lwd = 2) # line dividing groups
#dev.off()
#par(mfrow = c(1,1))
#
#
## PCA of in-group only
#pc = pca("snmf_input_western.geno", scale = T)
#
## Tracy Widon test (P< 0.05 has no support)
#tw = tracy.widom(pc)
#tw$pvalues[1:5]
#plot(tw$percentage)
## most likely number of clusters P< 0.01 K = 4

##########################################
# LEA Runs with Subsets #
##########################################
# A regularization parameter, alpha (a), controls the regularity of ancestry 
  # estimates over the geographic space. Large values of alpha imply that 
  # ancestry coefficients have similar values for nearby individuals, 
  # whereas small values produce results close to STRUCTURE. 
  # choosing the number of clusters
  # change K to the number of populations that you want to test

# The number of ancestral gene pools (K) and the regularization parameter (a) were chosen to minimize the cross-entropy criterion.

#### Neutral SNPs #####
# To choose the best alpha (a)
# Case 1: Plot all cross entropies for range of a across range of K
  # runtime was approx. 45 minutes

ce_a <- matrix(, nrow = 10, ncol = 21)
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
par(xpd = T, mar = c(3,3,3,10), mgp = c(2,1,0))
plot(0,0,type='n', xlim=c(0,21), ylim =c (0.5,0.8), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "neutral SNPs only")
#frame()
for (j in 1:10)
{
  r <- 0
  for (i in seq(from=0, to= 100, by=5))
  {
    r <- r+1
    obj.snmf = snmf("snmf_input_western_neu.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 10)
    ce_a[,r] <- cross.entropy(obj.snmf, K = j)
    best_a[r] <- min(ce_a[,r])
  }
  #x <- c(1:101)
  #lo <- loess(best_a~x
  lines(best_a, type='l', col =pal[j], lwd=2)
}
legend(22,0.7, horiz = F,
       legend=c("k=1","k=2", "k=3","k=4","k=5","k=6","k=7","k=8","k=9","k=10"),
       lty = 1, lwd=2, col= pal[1:10], cex = 0.6, ncol = 1)
axis(side = 1, at=c(0:20),
     labels = c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100))

# Case 2: Plot mean cross entropies for series of K at series of a
ce_a <- vector()
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
plot(0,0,type='n', xlim=c(0,101), ylim =c (0.5,0.7), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "Neutral SNPs Only")
for (i in seq(from=0, to= 100, by=5))
{
  r <- 0
  obj.snmf = snmf("snmf_input_western_neu.geno", K = 1:10,  ploidy = 2, entropy = T,
                  alpha = i, project = "new", repetitions = 10)
  for (j in 1:10)
  {
    r <- r+1
    ce_a[r] <- min(cross.entropy(obj.snmf, K = j))
  }
  best_a <- min(ce_a)
  points(i,best_a, type='b', col ="Red", lwd=2, pch=19)
}
axis(side = 1, at=x,
     labels = x)

# Best neutral alpha = 5, 90

#### Adaptive SNPs ####
# To choose the best alpha (a)
# Case 1: Plot all cross entropies for range of a across range of K
# runtime was approx. 45 minutes

ce_a <- matrix(, nrow = 10, ncol = 21)
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
par(xpd = T, mar = c(3,3,3,10), mgp = c(2,1,0))
plot(0,0,type='n', xlim=c(0,21), ylim =c (0.6,0.9), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "adaptive SNPs only")
#frame()
for (j in 1:10)
{
  r <- 0
  for (i in seq(from=0, to= 100, by=5))
  {
    r <- r+1
    obj.snmf = snmf("snmf_input_western_adap.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 10)
    ce_a[,r] <- cross.entropy(obj.snmf, K = j)
    best_a[r] <- min(ce_a[,r])
  }
  #x <- c(1:101)
  #lo <- loess(best_a~x
  lines(best_a, type='l', col =pal[j], lwd=2)
}
legend(22,0.7, horiz = F,
       legend=c("k=1","k=2", "k=3","k=4","k=5","k=6","k=7","k=8","k=9","k=10"),
       lty = 1, lwd=2, col= pal[1:10], cex = 0.6, ncol = 1)
axis(side = 1, at=c(0:20),
     labels = c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100))

# Case 2: Plot mean cross entropies for series of K at series of a
ce_a <- vector()
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
plot(0,0,type='n', xlim=c(0,101), ylim =c (0.6,0.8), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "Adaptive SNPs Only")
for (i in seq(from=0, to= 100, by=5))
{
  r <- 0
  obj.snmf = snmf("snmf_input_western_adap.geno", K = 1:10,  ploidy = 2, entropy = T,
                  alpha = i, project = "new", repetitions = 10)
  for (j in 1:10)
  {
    r <- r+1
    ce_a[r] <- min(cross.entropy(obj.snmf, K = j))
  }
  best_a <- min(ce_a)
  points(i,best_a, type='b', col ="Red", lwd=2, pch=19)
}
axis(side = 1, at=x,
     labels = x)

# Best adaptive alpha = 15, 60

#### Desert SNPs #####
# To choose the best alpha (a)
# Case 1: Plot all cross entropies for range of a across range of K
# runtime was approx. 45 minutes

ce_a <- matrix(, nrow = 10, ncol = 21)
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
par(xpd = T, mar = c(3,3,3,10), mgp = c(2,1,0))
plot(0,0,type='n', xlim=c(0,21), ylim =c (0.6,0.9), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "desert SNPs only")
#frame()
for (j in 1:10)
{
  r <- 0
  for (i in seq(from=0, to= 100, by=5))
  {
    r <- r+1
    obj.snmf = snmf("snmf_input_western_ste.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 10)
    ce_a[,r] <- cross.entropy(obj.snmf, K = j)
    best_a[r] <- min(ce_a[,r])
  }
  #x <- c(1:101)
  #lo <- loess(best_a~x
  lines(best_a, type='l', col =pal[j], lwd=2)
}
legend(22,0.7, horiz = F,
       legend=c("k=1","k=2", "k=3","k=4","k=5","k=6","k=7","k=8","k=9","k=10"),
       lty = 1, lwd=2, col= pal[1:10], cex = 0.6, ncol = 1)
axis(side = 1, at=c(0:20),
     labels = c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100))

# Case 2: Plot mean cross entropies for series of K at series of a
ce_a <- vector()
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
plot(0,0,type='n', xlim=c(0,101), ylim =c (0.6,0.8), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "desert SNPs Only")
for (i in seq(from=0, to= 100, by=5))
{
  r <- 0
  obj.snmf = snmf("snmf_input_western_ste.geno", K = 1:10,  ploidy = 2, entropy = T,
                  alpha = i, project = "new", repetitions = 10)
  for (j in 1:10)
  {
    r <- r+1
    ce_a[r] <- min(cross.entropy(obj.snmf, K = j))
  }
  best_a <- min(ce_a)
  points(i,best_a, type='b', col ="Red", lwd=2, pch=19)
}
axis(side = 1, at=x,
     labels = x)

# Best desert alpha = 55

#### Prairie SNPs ####
# To choose the best alpha (a)
# Case 1: Plot all cross entropies for range of a across range of K
# runtime was approx. 45 minutes

ce_a <- matrix(, nrow = 10, ncol = 21)
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
par(xpd = T, mar = c(3,3,3,10), mgp = c(2,1,0))
plot(0,0,type='n', xlim=c(0,21), ylim =c (0.5,0.9), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "prairie SNPs only")
#frame()
for (j in 1:10)
{
  r <- 0
  for (i in seq(from=0, to= 100, by=5))
  {
    r <- r+1
    obj.snmf = snmf("snmf_input_western_stt.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 10)
    ce_a[,r] <- cross.entropy(obj.snmf, K = j)
    best_a[r] <- min(ce_a[,r])
  }
  #x <- c(1:101)
  #lo <- loess(best_a~x
  lines(best_a, type='l', col =pal[j], lwd=2)
}
legend(22,0.7, horiz = F,
       legend=c("k=1","k=2", "k=3","k=4","k=5","k=6","k=7","k=8","k=9","k=10"),
       lty = 1, lwd=2, col= pal[1:10], cex = 0.6, ncol = 1)
axis(side = 1, at=c(0:20),
     labels = c(0,5,10,15,20,25,30,35,40,45,50,55,60,65,70,75,80,85,90,95,100))

# Case 2: Plot mean cross entropies for series of K at series of a
ce_a <- vector()
best_a <- vector()
x <- seq(from=0, to= 100, by=5)
plot(0,0,type='n', xlim=c(0,101), ylim =c (0.5,0.7), xaxt="n",
     xlab="Regularization Parameter (a)", ylab="Cross-Entropy",
     main = "prairie SNPs Only")
for (i in seq(from=0, to= 100, by=5))
{
  r <- 0
  obj.snmf = snmf("snmf_input_western_stt.geno", K = 1:10,  ploidy = 2, entropy = T,
                  alpha = i, project = "new", repetitions = 10)
  for (j in 1:10)
  {
    r <- r+1
    ce_a[r] <- min(cross.entropy(obj.snmf, K = j))
  }
  best_a <- min(ce_a)
  points(i,best_a, type='b', col ="Red", lwd=2, pch=19)
}
axis(side = 1, at=x,
     labels = x)

# Best prairie alpha = 5, 20, 100

#### Neutral SNPs 
obj.snmf = snmf("snmf_input_western_neu.geno", K = 1:10,  ploidy = 2, entropy = T,
                alpha = 90, project = "new", repetitions = 100)

# make plot of all k
pdf(paste0("western_K_entropy_neu_a90.pdf"),width = 3.5, height = 3.5)
plot(obj.snmf, col = "blue4", cex = 1.2, cex.axis = 1, cex.lab = 1.2,
     cex.main = 1.2, pch = 19, type='l')
main = paste0("western_individuals")
dev.off()

# best K = 3 (4,2,1) ; 1 (5, 3, 2)

#### Adaptive SNPs
obj.snmf = snmf("snmf_input_western_adap.geno", K = 1:10,  ploidy = 2, entropy = T,
                alpha = 60, project = "new", repetitions = 100)

# make plot of all k
pdf(paste0("western_K_entropy_adap_a60.pdf"),width = 3.5, height = 3.5)
plot(obj.snmf, col = "blue4", cex = 1.2, cex.axis = 1, cex.lab = 1.2,
     cex.main = 1.2, pch = 19, type='l')
main = paste0("western_individuals")
dev.off()

# best K = 4 (2, 3, 6, 5) ; 3, 2, 1

#### Desert SNPs
obj.snmf = snmf("snmf_input_western_ste.geno", K = 1:10,  ploidy = 2, entropy = T,
                alpha = 55, project = "new", repetitions = 100)

# make plot of all k
pdf(paste0("western_K_entropy_ste_a55.pdf"),width = 3.5, height = 3.5)
plot(obj.snmf, col = "blue4", cex = 1.2, cex.axis = 1, cex.lab = 1.2,
     cex.main = 1.2, pch = 19, type='l')
main = paste0("western_individuals")
dev.off()

# best K = 3 (1, 4, 2)

#### Prairie SNPs
obj.snmf = snmf("snmf_input_western_stt.geno", K = 1:10,  ploidy = 2, entropy = T,
                alpha = 100, project = "new", repetitions = 100)

# make plot of all k
pdf(paste0("western_K_entropy_stt_a100.pdf"),width = 3.5, height = 3.5)
plot(obj.snmf, col = "blue4", cex = 1.2, cex.axis = 1, cex.lab = 1.2,
     cex.main = 1.2, pch = 19, type='l')
main = paste0("western_individuals")
dev.off()

# best K = 2 ; 2 ; 1, 2, 4, 5 (3)

# neutral, a=25, k=2
# adaptive, a=30, k=3 (2, 6, 9)
# desert, a=15, k=4
# prairie, a=20, k=7 ... (2, 3, 4)

# neutral, a=5, k=3 (4,2,1)
#          a=90, k=1 (5, 3, 2)
# adaptive, a=15, k=4 (2, 3, 6, 5)
#           a=60, k=3, 2, 1
# desert, a=55, k=3 (1, 4, 2)
# prairie, a=5, k=2
#          a=20, k=2
#          a=100, k=1, 2, 4, 5 (3)

######################
# Actual Runs for all subsets
######################

# define color palette
pal <- choose_palette("OneLess")
pal <- (c("#9CA6B7", "#8E644F", "#383214", "#565030", "#C28A79", "#CCC8C9"))

### All SNPs Loop
# run SNMF for chosen K at subset alpha and whole dataset alpha
# all thirty repetitions of each k stored in snmf project in working directory after R session closes
alpha <- c(5,30)
kpop <- c(2,3,4,5)
best_run <- matrix(, nrow = length(alpha), ncol = max(kpop))
r <- 0
for (i in alpha)
{
  r <- r+1
  best_run[r,1] <- i
  # generate a figure of all plots for each alpha
    pdf(paste0("AllSNPs_western_structure_plot_a", i,".pdf"),width = 10, height = 7*length(kpop)/2)
    #tiff(paste0("AllSNPs_western_structure_plot_a", i,".pdf"),width = 700, height = 700*length(kpop)/2)
    par(mfrow=c(length(kpop),1))
  for (j in kpop)
  {
    obj.snmf = snmf("snmf_input_western.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 30)
    best_run[r,j] <- which.min(cross.entropy(obj.snmf, K = j))
    Qinit = as.data.frame(Q(obj.snmf, K = j, run = best_run[r,j])) # put admixture proportions for best run into matrix for plotting
      row.names(Qinit) <- stateID.order # Label samples
    # sort qmatrices for each subspecies by proportion of first ancestral population
      Qa <- Qinit[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
      Qb <- Qinit[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
      QaSort <- Qa[order(Qa$V1),] # sort by admixture proportion of first ancenstral population
      QbSort <- Qb[order(Qb$V1),] # same
      Qsorted <- rbind(QaSort,QbSort) # recombine subspecies matrices into single, sorted matrix
    assign(paste0("all.qmatrix.a",i,".k", j), Qsorted) # assign each Qmatrix to an individual dataframe
    write.csv(Qsorted, paste0("all.qmatrix.a",i,".k", j, ".csv"), row.names = T)
    # generate barplot
    barplot(t(Qsorted), col = c(pal), border = NA, 
            space = 0, xlab = "Individuals", axisnames = T, las = 3,
            ylab = paste0("Admixture coefficients (k=",j,")"), 
            cex = 0.5, cex.axis = 1, cex.lab = 1.2, cex.main = 1.2,  pch = 19)
    mtext("Desert", side = 1, at = 22, font = 2) # group label
    mtext("Prairie", side = 1, at = 60, font = 2) # group label
    abline(v = 44, lwd = 2) # line dividing groups
  }
  # turn off graphics parameters
  dev.off()
  par(mfrow = c(1,1))
}

### Neutral SNPs Loop
# run SNMF for chosen K at subset alpha and whole dataset alpha
# all thirty repetitions of each k stored in snmf project in working directory after R session closes
alpha <- c(5,90)
kpop <- c(2,3,4,5)
best_run <- matrix(, nrow = length(alpha), ncol = max(kpop))
r <- 0
for (i in alpha)
{
  r <- r+1
  best_run[r,1] <- i
  # generate a figure of all plots for each alpha
    pdf(paste0("NeuSNPs_western_structure_plot_a", i,".pdf"),width = 10, height = 7*length(kpop)/2)
    #tiff(paste0("NeuSNPs_western_structure_plot_a", i,".pdf"),width = 700, height = 700*length(kpop)/2)
    par(mfrow=c(length(kpop),1))
  for (j in kpop)
  {
    obj.snmf = snmf("snmf_input_western_neu.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 30)
    best_run[r,j] <- which.min(cross.entropy(obj.snmf, K = j))
    Qinit = as.data.frame(Q(obj.snmf, K = j, run = best_run[r,j])) # put admixture proportions for best run into matrix for plotting
      row.names(Qinit) <- stateID.order # Label samples
    # sort qmatrices for each subspecies by proportion of first ancestral population
      Qa <- Qinit[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
      Qb <- Qinit[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
      QaSort <- Qa[order(Qa$V1),] # sort by admixture proportion of first ancenstral population
      QbSort <- Qb[order(Qb$V1),] # same
      Qsorted <- rbind(QaSort,QbSort) # recombine subspecies matrices into single, sorted matrix
    assign(paste0("neu.qmatrix.a",i,".k", j), Qsorted) # assign each Qmatrix to an individual dataframe
    write.csv(Qsorted, paste0("neu.qmatrix.a",i,".k", j, ".csv"), row.names = T)
    # generate barplot
    barplot(t(Qsorted), col = c(pal), border = NA, 
            space = 0, xlab = "Individuals", axisnames = T, las = 3,
            ylab = paste0("Admixture coefficients (k=",j,")"), 
            cex = 0.5, cex.axis = 1, cex.lab = 1.2, cex.main = 1.2,  pch = 19)
      mtext("Desert", side = 1, at = 22, font = 2) # group label
      mtext("Prairie", side = 1, at = 60, font = 2) # group label
      abline(v = 44, lwd = 2) # line dividing groups
  }
  # turn off graphics parameters
  dev.off()
  par(mfrow = c(1,1))
}

### Adaptive SNPs Loop ###
# run SNMF for chosen K at subset alpha and whole dataset alpha
# all thirty repetitions of each k stored in snmf project in working directory after R session closes
alpha <- c(15,60)
kpop <- c(2,3,4,5)
best_run <- matrix(, nrow = length(alpha), ncol = max(kpop))
r <- 0
for (i in alpha)
{
  r <- r+1
  best_run[r,1] <- i
  # generate a figure of all plots for each alpha
    pdf(paste0("AdapSNPs_western_structure_plot_a", i,".pdf"),width = 10, height = 7*length(kpop)/2)
    #tiff(paste0("AdapSNPs_western_structure_plot_a", i,".pdf"),width = 700, height = 700*length(kpop)/2)
    par(mfrow=c(length(kpop),1))
  for (j in kpop)
  {
    obj.snmf = snmf("snmf_input_western_adap.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 30)
    best_run[r,j] <- which.min(cross.entropy(obj.snmf, K = j))
    Qinit = as.data.frame(Q(obj.snmf, K = j, run = best_run[r,j])) # put admixture proportions for best run into matrix for plotting
      row.names(Qinit) <- stateID.order # Label samples
    # sort qmatrices for each subspecies by proportion of first ancestral population
      Qa <- Qinit[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
      Qb <- Qinit[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
      QaSort <- Qa[order(Qa$V1),] # sort by admixture proportion of first ancenstral population
      QbSort <- Qb[order(Qb$V1),] # same
      Qsorted <- rbind(QaSort,QbSort) # recombine subspecies matrices into single, sorted matrix
    assign(paste0("adap.qmatrix.a",i,".k", j), Qsorted) # assign each Qmatrix to an individual dataframe
    write.csv(Qsorted, paste0("adap.qmatrix.a",i,".k", j, ".csv"), row.names = T)
    # generate barplot
    barplot(t(Qsorted), col = c(pal), border = NA, 
            space = 0, xlab = "Individuals", axisnames = T, las = 3,
            ylab = paste0("Admixture coefficients (k=",j,")"), 
            cex = 0.5, cex.axis = 1, cex.lab = 1.2, cex.main = 1.2,  pch = 19)
    mtext("Desert", side = 1, at = 22, font = 2) # group label
    mtext("Prairie", side = 1, at = 60, font = 2) # group label
    abline(v = 44, lwd = 2) # line dividing groups
  }
  # turn off graphics parameters
  dev.off()
  par(mfrow = c(1,1))
}


### Desert SNPs Loop
# run SNMF for chosen K at subset alpha and whole dataset alpha
# all thirty repetitions of each k stored in snmf project in working directory after R session closes
alpha <- c(55)
kpop <- c(2,3,4,5)
best_run <- matrix(, nrow = length(alpha), ncol = max(kpop))
r <- 0
for (i in alpha)
{
  r <- r+1
  best_run[r,1] <- i
  # generate a figure of all plots for each alpha
    pdf(paste0("steSNPs_western_structure_plot_a", i,".pdf"),width = 10, height = 7*length(kpop)/2)
    #tiff(paste0("steSNPs_western_structure_plot_a", i,".pdf"),width = 700, height = 700*length(kpop)/2)
    par(mfrow=c(length(kpop),1))
  for (j in kpop)
  {
    obj.snmf = snmf("snmf_input_western_ste.geno", K = j,  ploidy = 2, entropy = T,
                        alpha = i, project = "new", repetitions = 30)
    best_run[r,j] <- which.min(cross.entropy(obj.snmf, K = j))
    Qinit = as.data.frame(Q(obj.snmf, K = j, run = best_run[r,j])) # put admixture proportions for best run into matrix for plotting
      row.names(Qinit) <- stateID.order # Label samples
    # sort qmatrices for each subspecies by proportion of first ancestral population
      Qa <- Qinit[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
      Qb <- Qinit[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
      QaSort <- Qa[order(Qa$V1),] # sort by admixture proportion of first ancenstral population
      QbSort <- Qb[order(Qb$V1),] # same
      Qsorted <- rbind(QaSort,QbSort) # recombine subspecies matrices into single, sorted matrix
    assign(paste0("ste.qmatrix.a",i,".k", j), Qsorted) # assign each Qmatrix to an individual dataframe
    write.csv(Qsorted, paste0("ste.qmatrix.a",i,".k", j, ".csv"), row.names = T)
    # generate barplot
    barplot(t(Qsorted), col = c(pal), border = NA, 
            space = 0, xlab = "Individuals", axisnames = T, las = 3,
            ylab = paste0("Admixture coefficients (k=",j,")"), 
            cex = 0.5, cex.axis = 1, cex.lab = 1.2, cex.main = 1.2,  pch = 19)
      mtext("Desert", side = 1, at = 22, font = 2) # group label
      mtext("Prairie", side = 1, at = 60, font = 2) # group label
      abline(v = 44, lwd = 2) # line dividing groups
  }
  # turn off graphics parameters
  dev.off()
  par(mfrow = c(1,1))
}


### Prairie SNPs Loop
# run SNMF for chosen K at subset alpha and whole dataset alpha
# all thirty repetitions of each k stored in snmf project in working directory after R session closes
alpha <- c(5,20,100)
kpop <- c(2,3,4,5)
best_run <- matrix(, nrow = length(alpha), ncol = max(kpop))
r <- 0
for (i in alpha)
{
  r <- r+1
  best_run[r,1] <- i
  # generate a figure of all plots for each alpha
    pdf(paste0("sttSNPs_western_structure_plot_a", i,".pdf"),width = 10, height = 7*length(kpop)/2)
    #tiff(paste0("sttSNPs_western_structure_plot_a", i,".pdf"),width = 700, height = 700*length(kpop)/2)
    par(mfrow=c(length(kpop),1))
  for (j in kpop)
  {
    obj.snmf = snmf("snmf_input_western_stt.geno", K = j,  ploidy = 2, entropy = T,
                    alpha = i, project = "new", repetitions = 30)
    best_run[r,j] <- which.min(cross.entropy(obj.snmf, K = j))
    Qinit = as.data.frame(Q(obj.snmf, K = j, run = best_run[r,j])) # put admixture proportions for best run into matrix for plotting
      row.names(Qinit) <- stateID.order # Label samples
    # sort qmatrices for each subspecies by proportion of first ancestral population
      Qa <- Qinit[1:44,] # extract data from qmatrix for each subspecies (desert massasauga)
      Qb <- Qinit[45:78,] # extract data from qmatrix for each subspecies (prairie massasauga) 
      QaSort <- Qa[order(Qa$V1),] # sort by admixture proportion of first ancenstral population
      QbSort <- Qb[order(Qb$V1),] # same
      Qsorted <- rbind(QaSort,QbSort) # recombine subspecies matrices into single, sorted matrix
    assign(paste0("stt.qmatrix.a",i,".k", j), Qsorted) # assign each Qmatrix to an individual dataframe
    write.csv(Qsorted, paste0("stt.qmatrix.a",i,".k", j, ".csv"), row.names = T)
    # generate barplot
    barplot(t(Qsorted), col = c(pal), border = NA, 
            space = 0, xlab = "Individuals", axisnames = T, las = 3,
            ylab = paste0("Admixture coefficients (k=",j,")"), 
            cex = 0.5, cex.axis = 1, cex.lab = 1.2, cex.main = 1.2,  pch = 19)
    mtext("Desert", side = 1, at = 22, font = 2) # group label
    mtext("Prairie", side = 1, at = 60, font = 2) # group label
    abline(v = 44, lwd = 2) # line dividing groups
  }
  # turn off graphics parameters
  dev.off()
  par(mfrow = c(1,1))
}

# generate Fig5.tif (LEA plot for all loci alpha = 5, k = 2)
qmatrix2Sorted <- read.csv("neu.qmatrix.a5.k2.csv", header = T)
row.names(qmatrix2Sorted) <- qmatrix2Sorted[,1]
qmatrix2Sorted <- qmatrix2Sorted[,2:3]
tiff("Fig5.tif", width = 2700, height = 900)
par(mar=c(25,15,10,5))
barplot(t(qmatrix2Sorted), col = c(pal), border = NA, 
        space = 0, axisnames = T, las = 3,
        cex = 2, cex.axis = 2)
mtext("Individuals", side = 1, padj = 8, font = 2, cex = 3.6) # x-axis label
mtext("Admixture Coefficients (k=2)", side = 2, padj = -4, font = 2, cex = 3.6) # y-axis label
mtext("Desert", side = 3, at = 22, font = 2, cex = 3.6) # group label
mtext("Prairie", side = 3, at = 60, font = 2, cex = 3.6) # group label
abline(v = 44, lwd = 6) # line dividing groups
dev.off()

#END

