#adegenet and mantel test
library(MASS)
library(adegenet)
library(PBSmapping)
library(factoextra)
library(poppr)
library(HardyWeinberg)
library(pegas)

#setwd("D:/DeWoody Lab/Massasauga Rattlesnakes/scripts and outputs/")
setwd("C:/Users/Rian/Desktop/scripts and outputs/")

# read in data from genepop format and convert to genind object
# allele names cannot have a '.' in them
# converts data frame to "genind" object
# keeps only genotypes
my.genind.het <- read.genepop("adegenet_input_western_all_heterozygosity.gen", ncode = 2, quiet = F)
View(my.genind.het)
str(my.genind.het)
# summary of heterozygosity for each locus (obs and exp)
summary <- summary(my.genind.het)
summary
names(summary)
# plot heterozygosity at each locus
plot(summary$Hobs, xlab="Locus", ylab="Observed Heterozygosity", 
     main="Observed heterozygosity, each locus")
# plot He by Ho
plot(summary$Hobs, summary$Hexp, xlab="Hobs", ylab="Hexp", 
     main="Expected heterozygosity as a function of observed heterozygosity per locus")
# Bartlett test
bartlett.test(list(summary$Hexp, summary$Hobs)) # a test : H0: Hexp = Hobs
chisq.test(summary$Hobs, summary$Hexp)
summary$Hexp
mean(summary$Hobs)
sd(summary$Hobs)
mean(summary$Hexp)
sd(summary$Hexp)
# Wahlund test
my.fst <- read.csv("fst.csv", header = T, na.strings = "-") # a spreadsheet with 10 columns: locus, fst value (all, intergenic, genic, desert, prairie, intergenic_desert, genic_desert, intergenic_prairie, genic_prairie)
str(my.fst)
#my.fis <- read.csv("genepop_HW_western_onepop.csv", na.strings = c("No", "information.", "", "NA")) # a spreadsheet with values for fis. See genepop_analysis.R script
my.fis <- read.csv("fis.csv", header = T, na.strings = c("NA","-", "")) # a spreadsheet with 10 columns: locus, fst value (all, intergenic, genic, desert, prairie, intergenic_desert, genic_desert, intergenic_prairie, genic_prairie)
str(my.fis)
wahlund <- matrix(nrow = 10, ncol = 7)
wahlund[1,] <- c("subset", "fst_mean", "fst_sd", "fst_positive?", "slope_mean", "slope_sd", "adj.Rsquared")
for(boop in 2:10) {
        wahlund[boop,1] <- colnames(my.fst[boop])
        plot(my.fst[,boop], my.fis[,boop], main = colnames(my.fst[boop]))
        wahlund[boop,2] <- mean(my.fis[,boop], na.rm = T)
        wahlund[boop,3] <- sd(my.fis[,boop], na.rm = T)
        wahlund[boop,4] <- mean(my.fis[,boop], na.rm = T) - sd(my.fis[,boop], na.rm = T)
        #cor.test(my.fis[,s], my.fst[,s], method = "pearson")
        fis.fst <- lm(my.fis[,boop] ~ my.fst[,boop])
        summ <- summary(fis.fst)
        wahlund[boop,5] <- summ$coefficients[2,1]
        wahlund[boop,6] <- summ$coefficients[2,2]
        wahlund[boop,7] <- summ$adj.r.squared 
        }
write.table(as.data.frame(wahlund), file = "wahlund.csv", na = "", quote = F, col.names = F, sep = ",", row.names = F)

# calculate allele frequencies
polymorphism <- isPoly(my.genind.het, by=c("locus","allele"), thres=1/100)
# check for loci with MAF < 0.01
informloci(my.genind.het, cutoff = 1/nInd(my.genind.het), MAF = 0.01, quiet = FALSE)

# read in a table with county centroid easting and northing in the same order as the genepop input
table.w.sample.names <- read.csv("Genotyping results Western.csv", header = T)
easting <- table.w.sample.names$centroid.easting
northing <- table.w.sample.names$centroid.northing
# scale easting and northing values to 1
easting.corr <- abs(easting)-max(abs(easting))
easting.scaled <- easting.corr/min(easting.corr)
easting.scaled
northing.corr <- northing-min(northing)
northing.scaled <- northing.corr/max(northing.corr)
northing.scaled
geo.coords <- cbind(easting.scaled, northing.scaled)
row.names(geo.coords) <- table.w.sample.names$Sample
geo.coords

# read in data from genepop format and convert to genind object
# allele names cannot have a '.' in them
# converts data frame to "genind" object
# keeps only genotypes
my.genind.all <- read.genepop("adegenet_input_all.gen", ncode = 2, quiet = F)
View(my.genind.all)
str(my.genind.all)
# check for loci with MAF < 0.01
informloci(my.genind.all, cutoff = 1/nInd(my.genind.all), MAF = 0.01, quiet = FALSE)
# remove loci with MAF < 0.01
my.genind.all <- informloci(my.genind.all, cutoff = 1/nInd(my.genind.all), MAF = 0.01, quiet = FALSE)
View(my.genind.all)
str(my.genind.all)

my.genind.western <- read.genepop("adegenet_input_western.gen", ncode = 2, quiet = F)
View(my.genind.western)
str(my.genind.western)
# check for loci with MAF < 0.01
informloci(my.genind.western, cutoff = 1/nInd(my.genind.western), MAF = 0.01, quiet = FALSE)
# remove loci with MAF < 0.01
my.genind.western <- informloci(my.genind.western, cutoff = 1/nInd(my.genind.western), MAF = 0.01, quiet = FALSE)
View(my.genind.western)
str(my.genind.western)

#########
## PCA ##
#########
# define color palette from zhangyimou.R
pal <- choose_palette("OneLess")
pal <- (c("#9CA6B7", "#8E644F", "#383214", "#565030", "#C28A79", "#CCC8C9"))


# PCAs
all <- my.genind.all
All <- scaleGen(all, NA.method="mean")
pca1 <- dudi.pca(All,cent=FALSE,scale=FALSE,scannf=FALSE, nf=3)
        barplot(pca1$eig[1:50],main="PCA eigenvalues", col=heat.colors(50))
        s.class(pca1$li,pop(all),xax=1,yax=2,sub="PCA 1-2",csub=2, col = c("darkgoldenrod4", "darkorchid4", "sienna4"))
# PCA for Western Massasauga
west <- my.genind.western
str(west)
# Rename by populations
levels(west$pop)[levels(west$pop)=="MF22092"] <- "Desert"
levels(west$pop)[levels(west$pop)=="TJH3618"] <- "Prairie"
str(west)
West <- scaleGen(west, NA.method="mean")
pca2 <- dudi.pca(West,cent=FALSE,scale=FALSE,scannf=FALSE, nf = 16)
        screeplot(pca2, main = "Screeplot - Eigenvalues") # screeplot showing proportion of inertia in each eigenvector
        barplot(pca2$eig[1:50],main="PCA eigenvalues", col=heat.colors(50)) # heatmap of screeplot above
        summary(pca2) # summary of pca results -- in depth look below
        s.corcircle(pca2$co,xax=1,yax=2, clabel = F) # graphical depiction of eigenvectors in PC1xPC2 space
        eig.val <- get_eigenvalue(pca2) # get eigenvalues
        eig.val # use column 2 (variance.percent) to label axes
        res.var <- get_pca_var(pca2) # extract data for alleles (variables)
           res.var$coord # Coordinates in eigenspace
           res.var$contrib # Contributions to the PCs
                sort(res.var$contrib[,1]) # alleles at end of list contribut most to PC1
                  barplot(sort(res.var$contrib[,1])) # visualize contribution to PC1
                sort(res.var$contrib[,2]) # alleles at end of list contribut most to PC2
                  barplot(sort(res.var$contrib[,2])) # visualize contribution to PC2
                sort(res.var$contrib[,3]) # alleles at end of list contribut most to PC3
                  barplot(sort(res.var$contrib[,3])) # visualize contribution to PC3
           res.var$cos2 # Quality of representation 
        res.ind <- get_pca_ind(pca2) # extract data for individuals (samples)
           res.ind$coord # Coordinates
                sort(res.ind$coord[,1]) # individual coords on pc1 - compare to list with names to dig into shape of data
                sort(res.ind$coord[,2]) # individual coords on pc2 - compare to list with names to dig into shape of data
           res.ind$contrib # Contributions to the PCs
           res.ind$cos2 # Quality of representation 
        s.class(pca2$li,pop(west),xax=1,yax=2,sub="PCA 1,2",csub=2, col = c("darkgoldenrod3", "chartreuse4"))
        s.class(pca2$li, pop(west), xax=1, yax=2, # define PCA, population splits, and axes to plot
                col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
                axesell=F, cstar=0, grid=F, cellipse = 0, #clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
                cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
                #sub="Desert\n  Prairie", csub = 1, possub = "topright", # title
                )
                mtext("PCA1: 6.8% variance", side = 1, padj = 5.5, font = 2, at = 7) # horizontal axis label
                mtext("PCA2: 4.5% variance", side = 2, padj = -4, font = 2, at = 6) # vertical axis label
                #mtext("Desert", side = 3, padj = -4, font = 2, at = 12) # vertical axis label
                #mtext("Prairie", side = 3, padj = -2, font = 2, at = 12) # vertical axis label
                #points(c(2, 7), y = c(8, 6), pch = c(18, 20), )
                #legend("bottomleft", legend=c("Desert", "Prairie"), cex = 1,
                #       col=transp(c("darkgoldenrod3", "chartreuse4"),.6), pch = c(18, 20), pt.cex=2,
                #       )
        s.class(pca2$li, pop(west), xax=3, yax=4, # define PCA, population splits, and axes to plot
                col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
                axesell=F, cstar=0, grid=F, #cellipse = 1, # plot grid and basics, no lines connecting to centroid, no ellipse
                cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
                sub="PCs 3,4", csub = 1.5, possub = "topright" # title
                )
#Fig4
tiff("Fig4.tif", width = 900, height = 900)
par(mar = c(3.1, 4.1, 4.1, 2.1))
s.class(pca2$li, pop(west), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c(pal[1:2]),.6), # colors
        #col=rgb(test$geo[,1],test$geo[,2],0,.6), # color by county centroid
        axesell=F, cstar=0, grid=F, cellipse = 0, clabel = 2,#clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=4, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        )
mtext("PC 1: 6.8% variance", side = 1, padj = 1, font = 2, at = 5, cex = 2, bg = NA) # horizontal axis label
mtext("PC 2: 4.5% variance", side = 2, padj = -1.7, font = 2, at = 6, cex = 2, bg = NA) # vertical axis label
mtext("Missouri", side = 1, padj = -29, font = 2, at = 8, cex = 2, col = pal[4]) # label MO sample
mtext("Matagorda Island", side = 1, padj = -7, font = 2, at = 7, cex = 2, col = pal[4]) # label Matagorda Island samples
mtext("Arizona", side = 1, padj = -15, font = 2, at = -9, cex = 2, col = pal[4]) # label AZ samples
#mtext("Colorado", side = 1, padj = -5, font = 2, at = 7, cex = 2, col = pal[4]) # label CO samples
symbols(res.ind$coord[row.names(res.ind$coord) == "TJH4017",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #Matagorda
symbols(res.ind$coord[row.names(res.ind$coord) == "TJH4018",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #Matagorda
symbols(res.ind$coord[row.names(res.ind$coord) == "TJH4019",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #Matagorda
symbols(res.ind$coord[row.names(res.ind$coord) == "FHSM9971",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #MO
symbols(res.ind$coord[row.names(res.ind$coord) == "SCed054",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #AZ
symbols(res.ind$coord[row.names(res.ind$coord) == "SCed081",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #AZ
symbols(res.ind$coord[row.names(res.ind$coord) == "SCed101",1:2], circles = 0.4, fg = pal[4], add = T, inches = F, lwd = 4) #AZ
dev.off()

# preliminary PCA for Neutral SNPs - note: non-HWE loci retained
neu <- read.genepop("genepop_input_western_neu.gen")
str(neu)
#remove loci with MAF < 0.01
neu <- informloci(neu, cutoff = 1/nInd(neu), MAF = 0.01, quiet = FALSE)
# Rename by populations
levels(neu$pop)[levels(neu$pop)=="MF22092"] <- "Desert"
levels(neu$pop)[levels(neu$pop)=="TJH3618"] <- "Prairie"
str(neu)
scaled.neu <- scaleGen(neu, NA.method="mean")
pca.neu <- dudi.pca(scaled.neu,cent=FALSE,scale=FALSE,scannf=FALSE, nf = 16)
        screeplot(pca.neu, main = "Screeplot - Eigenvalues") # screeplot showing proportion of inertia in each eigenvector
        barplot(pca.neu$eig[1:50],main="PCA eigenvalues", col=heat.colors(50)) # heatmap of screeplot above
        summary(pca.neu) # summary of pca results -- in depth look below
        s.corcircle(pca.neu$co,xax=1,yax=2, clabel = F) # graphical depiction of eigenvectors in PC1xPC2 space
        eig.val <- get_eigenvalue(pca.neu) # get eigenvalues
        eig.val # use column 2 (variance.percent) to label axes
        res.var <- get_pca_var(pca.neu) # extract data for alleles (variables)
                res.var$coord # Coordinates in eigenspace
                res.var$contrib # Contributions to the PCs
                sort(res.var$contrib[,1]) # alleles at end of list contribut most to PC1
        barplot(sort(res.var$contrib[,1])) # visualize contribution to PC1
                sort(res.var$contrib[,2]) # alleles at end of list contribut most to PC2
        barplot(sort(res.var$contrib[,2])) # visualize contribution to PC2
                sort(res.var$contrib[,3]) # alleles at end of list contribut most to PC3
        barplot(sort(res.var$contrib[,3])) # visualize contribution to PC3
                res.var$cos2 # Quality of representation 
                res.ind <- get_pca_ind(pca.neu) # extract data for individuals (samples)
                res.ind$coord # Coordinates
                sort(res.ind$coord[,1]) # individual coords on pc1 - compare to list with names to dig into shape of data
                sort(res.ind$coord[,2]) # individual coords on pc2 - compare to list with names to dig into shape of data
        # Description of sample layout here
                res.ind$contrib # Contributions to the PCs
                res.ind$cos2 # Quality of representation 
s.class(pca.neu$li, pop(neu),xax=1,yax=2,sub="PCA 1,2",csub=2, col = c("darkgoldenrod3", "chartreuse4"))
s.class(pca.neu$li, pop(neu), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, #clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        #sub="Desert\n  Prairie", csub = 1, possub = "topright", # title
        )
        mtext("PC 1: 6.3% variance", side = 1, padj = 5.5, font = 2, at = 6) # horizontal axis label
        mtext("PC 2: 4.8% variance", side = 2, padj = -4, font = 2, at = -3.5) # vertical axis label
        #mtext("Desert", side = 3, padj = -4, font = 2, at = 12) # vertical axis label
        #mtext("Prairie", side = 3, padj = -2, font = 2, at = 12) # vertical axis label
        #points(c(2, 7), y = c(8, 6), pch = c(18, 20), )
        #legend("bottomleft", legend=c("Desert", "Prairie"), cex = 1,
        #col=transp(c("darkgoldenrod3", "chartreuse4"),.6), pch = c(18, 20), pt.cex=2,
        #)
s.class(pca.neu$li, pop(neu), xax=3, yax=4, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, #cellipse = 1, # plot grid and basics, no lines connecting to centroid, no ellipse
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        sub="PCs 3,4", csub = 1.5, possub = "topright" # title
        )
#Figure
tiff("PCA.neu.tif", width = 900, height = 900)
s.class(pca.neu$li, pop(neu), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c(pal[1:2]),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, clabel = 2,#clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=4, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        )
        mtext("PC 1: 6.3% variance", side = 1, padj = 3, font = 2, at = 4, cex = 2) # horizontal axis label
        mtext("PC 2: 4.8% variance", side = 2, padj = -1.7, font = 2, at = 3, cex = 2) # vertical axis label
dev.off()

# preliminary PCA for Adaptive SNPs - note: non-HWE loci retained
adap <- read.genepop("genepop_input_western_adap.gen")
str(adap)
#remove loci with MAF < 0.01
adap <- informloci(adap, cutoff = 1/nInd(adap), MAF = 0.01, quiet = FALSE)
# Rename by populations
levels(adap$pop)[levels(adap$pop)=="MF22092"] <- "Desert"
levels(adap$pop)[levels(adap$pop)=="TJH3618"] <- "Prairie"
str(adap)
scaled.adap <- scaleGen(adap, NA.method="mean")
pca.adap <- dudi.pca(scaled.adap,cent=FALSE,scale=FALSE,scannf=FALSE, nf = 16)
        screeplot(pca.adap, main = "Screeplot - Eigenvalues") # screeplot showing proportion of inertia in each eigenvector
        barplot(pca.adap$eig[1:50],main="PCA eigenvalues", col=heat.colors(50)) # heatmap of screeplot above
        summary(pca.adap) # summary of pca results -- in depth look below
        s.corcircle(pca.adap$co,xax=1,yax=2, clabel = F) # graphical depiction of eigenvectors in PC1xPC2 space
        eig.val <- get_eigenvalue(pca.adap) # get eigenvalues
                eig.val # use column 2 (variance.percent) to label axes
        res.var <- get_pca_var(pca.adap) # extract data for alleles (variables)
                res.var$coord # Coordinates in eigenspace
                res.var$contrib # Contributions to the PCs
        sort(res.var$contrib[,1]) # alleles at end of list contribut most to PC1
                barplot(sort(res.var$contrib[,1])) # visualize contribution to PC1
        sort(res.var$contrib[,2]) # alleles at end of list contribut most to PC2
                barplot(sort(res.var$contrib[,2])) # visualize contribution to PC2
        sort(res.var$contrib[,3]) # alleles at end of list contribut most to PC3
                barplot(sort(res.var$contrib[,3])) # visualize contribution to PC3
        res.var$cos2 # Quality of representation 
        res.ind <- get_pca_ind(pca.adap) # extract data for individuals (samples)
                res.ind$coord # Coordinates
                sort(res.ind$coord[,1]) # individual coords on pc1 - compare to list with names to dig into shape of data
                sort(res.ind$coord[,2]) # individual coords on pc2 - compare to list with names to dig into shape of data
        # Description of sample layout here
                res.ind$contrib # Contributions to the PCs
                res.ind$cos2 # Quality of representation 
s.class(pca.adap$li, pop(adap),xax=1,yax=2,sub="PCA 1,2",csub=2, col = c("darkgoldenrod3", "chartreuse4"))
s.class(pca.adap$li, pop(adap), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, #clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        #sub="Desert\n  Prairie", csub = 1, possub = "topright", # title
        )
        mtext("PC 1: 7.9% variance", side = 1, padj = 5.5, font = 2, at = 7) # horizontal axis label
        mtext("PC 2: 5.7% variance", side = 2, padj = -4, font = 2, at = 5) # vertical axis label
        #mtext("Desert", side = 3, padj = -4, font = 2, at = 12) # vertical axis label
        #mtext("Prairie", side = 3, padj = -2, font = 2, at = 12) # vertical axis label
        #points(c(2, 7), y = c(8, 6), pch = c(18, 20), )
        #legend("bottomleft", legend=c("Desert", "Prairie"), cex = 1,
        #col=transp(c("darkgoldenrod3", "chartreuse4"),.6), pch = c(18, 20), pt.cex=2,
        #)
s.class(pca.adap$li, pop(adap), xax=3, yax=4, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, #cellipse = 1, # plot grid and basics, no lines connecting to centroid, no ellipse
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        sub="PCs 3,4", csub = 1.5, possub = "topright" # title
        )
#Figure
tiff("PCA.adap.tif", width = 900, height = 900)
s.class(pca.adap$li, pop(adap), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c(pal[1:2]),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, clabel = 2,#clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=4, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        )
        mtext("PC 1: 7.9% variance", side = 1, padj = 3, font = 2, at = 4, cex = 2) # horizontal axis label
        mtext("PC 2: 5.7% variance", side = 2, padj = -1.7, font = 2, at = 6, cex = 2) # vertical axis label
dev.off()

# preliminary PCA for Desert SNPs - note: non-HWE loci retained
ste <- read.genepop("genepop_input_western_ste.gen")
str(ste)
#remove loci with MAF < 0.01
ste <- informloci(ste, cutoff = 1/nInd(ste), MAF = 0.01, quiet = FALSE)
# Rename by populations
levels(ste$pop)[levels(ste$pop)=="MF22092"] <- "Desert"
levels(ste$pop)[levels(ste$pop)=="TJH3618"] <- "Prairie"
str(ste)
scaled.ste <- scaleGen(ste, NA.method="mean")
pca.ste <- dudi.pca(scaled.ste,cent=FALSE,scale=FALSE,scannf=FALSE, nf = 16)
        screeplot(pca.ste, main = "Screeplot - Eigenvalues") # screeplot showing proportion of inertia in each eigenvector
        barplot(pca.ste$eig[1:50],main="PCA eigenvalues", col=heat.colors(50)) # heatmap of screeplot above
        summary(pca.ste) # summary of pca results -- in depth look below
        s.corcircle(pca.ste$co,xax=1,yax=2, clabel = F) # graphical depiction of eigenvectors in PC1xPC2 space
        eig.val <- get_eigenvalue(pca.ste) # get eigenvalues
                eig.val # use column 2 (variance.percent) to label axes
        res.var <- get_pca_var(pca.ste) # extract data for alleles (variables)
                res.var$coord # Coordinates in eigenspace
                res.var$contrib # Contributions to the PCs
        sort(res.var$contrib[,1]) # alleles at end of list contribut most to PC1
                barplot(sort(res.var$contrib[,1])) # visualize contribution to PC1
        sort(res.var$contrib[,2]) # alleles at end of list contribut most to PC2
                barplot(sort(res.var$contrib[,2])) # visualize contribution to PC2
        sort(res.var$contrib[,3]) # alleles at end of list contribut most to PC3
                barplot(sort(res.var$contrib[,3])) # visualize contribution to PC3
        res.var$cos2 # Quality of representation 
        res.ind <- get_pca_ind(pca.ste) # extract data for individuals (samples)
                res.ind$coord # Coordinates
                sort(res.ind$coord[,1]) # individual coords on pc1 - compare to list with names to dig into shape of data
                sort(res.ind$coord[,2]) # individual coords on pc2 - compare to list with names to dig into shape of data
        # Description of sample layout here
                res.ind$contrib # Contributions to the PCs
                res.ind$cos2 # Quality of representation 
s.class(pca.ste$li, pop(ste),xax=1,yax=2,sub="PCA 1,2",csub=2, col = c("darkgoldenrod3", "chartreuse4"))
s.class(pca.ste$li, pop(ste), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, #clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        #sub="Desert\n  Prairie", csub = 1, possub = "topright", # title
        )
        mtext("PC 1: 8.5% variance", side = 1, padj = 5.5, font = 2, at = 7) # horizontal axis label
        mtext("PC 2: 5.5% variance", side = 2, padj = -4, font = 2, at = -5) # vertical axis label
        #mtext("Desert", side = 3, padj = -4, font = 2, at = 12) # vertical axis label
        #mtext("Prairie", side = 3, padj = -2, font = 2, at = 12) # vertical axis label
        #points(c(2, 7), y = c(8, 6), pch = c(18, 20), )
        #legend("bottomleft", legend=c("Desert", "Prairie"), cex = 1,
        #col=transp(c("darkgoldenrod3", "chartreuse4"),.6), pch = c(18, 20), pt.cex=2,
        #)
s.class(pca.ste$li, pop(ste), xax=3, yax=4, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, #cellipse = 1, # plot grid and basics, no lines connecting to centroid, no ellipse
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        sub="PCs 3,4", csub = 1.5, possub = "topright" # title
        )
#Figure
tiff("PCA.ste.tif", width = 900, height = 900)
s.class(pca.ste$li, pop(ste), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c(pal[1:2]),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, clabel = 2,#clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=4, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        )
        mtext("PC 1: 7.5% variance", side = 1, padj = 3, font = 2, at = 3, cex = 2) # horizontal axis label
        mtext("PC 2: 5.5% variance", side = 2, padj = -1.7, font = 2, at = -6, cex = 2) # vertical axis label
dev.off()

# preliminary PCA for Prairie SNPs - note: non-HWE loci retained
stt <- read.genepop("genepop_input_western_stt.gen")
str(stt)
#remove loci with MAF < 0.01
stt <- informloci(stt, cutoff = 1/nInd(stt), MAF = 0.01, quiet = FALSE)
# Rename by populations
levels(stt$pop)[levels(stt$pop)=="MF22092"] <- "Desert"
levels(stt$pop)[levels(stt$pop)=="TJH3618"] <- "Prairie"
str(stt)
scaled.stt <- scaleGen(stt, NA.method="mean")
pca.stt <- dudi.pca(scaled.stt,cent=FALSE,scale=FALSE,scannf=FALSE, nf = 16)
        screeplot(pca.stt, main = "Screeplot - Eigenvalues") # screeplot showing proportion of inertia in each eigenvector
        barplot(pca.stt$eig[1:50],main="PCA eigenvalues", col=heat.colors(50)) # heatmap of screeplot above
        summary(pca.stt) # summary of pca results -- in depth look below
        s.corcircle(pca.stt$co,xax=1,yax=2, clabel = F) # graphical depiction of eigenvectors in PC1xPC2 space
        eig.val <- get_eigenvalue(pca.stt) # get eigenvalues
                eig.val # use column 2 (variance.percent) to label axes
        res.var <- get_pca_var(pca.stt) # extract data for alleles (variables)
                res.var$coord # Coordinates in eigenspace
                res.var$contrib # Contributions to the PCs
        sort(res.var$contrib[,1]) # alleles at end of list contribut most to PC1
                barplot(sort(res.var$contrib[,1])) # visualize contribution to PC1
        sort(res.var$contrib[,2]) # alleles at end of list contribut most to PC2
                barplot(sort(res.var$contrib[,2])) # visualize contribution to PC2
        sort(res.var$contrib[,3]) # alleles at end of list contribut most to PC3
                barplot(sort(res.var$contrib[,3])) # visualize contribution to PC3
        res.var$cos2 # Quality of representation 
        res.ind <- get_pca_ind(pca.stt) # extract data for individuals (samples)
                res.ind$coord # Coordinates
                sort(res.ind$coord[,1]) # individual coords on pc1 - compare to list with names to dig into shape of data
                sort(res.ind$coord[,2]) # individual coords on pc2 - compare to list with names to dig into shape of data
        # Description of sample layout here
                res.ind$contrib # Contributions to the PCs
                res.ind$cos2 # Quality of representation 
s.class(pca.stt$li, pop(stt),xax=1,yax=2,sub="PCA 1,2",csub=2, col = c("darkgoldenrod3", "chartreuse4"))
s.class(pca.stt$li, pop(stt), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, #clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        #sub="Desert\n  Prairie", csub = 1, possub = "topright", # title
        )
        mtext("PC 1: 6.8% variance", side = 1, padj = 5.5, font = 2, at = 7) # horizontal axis label
        mtext("PC 2: 4.7% variance", side = 2, padj = -4, font = 2, at = -5) # vertical axis label
        #mtext("Desert", side = 3, padj = -4, font = 2, at = 12) # vertical axis label
        #mtext("Prairie", side = 3, padj = -2, font = 2, at = 12) # vertical axis label
        #points(c(2, 7), y = c(8, 6), pch = c(18, 20), )
        #legend("bottomleft", legend=c("Desert", "Prairie"), cex = 1,
        #col=transp(c("darkgoldenrod3", "chartreuse4"),.6), pch = c(18, 20), pt.cex=2,
        #)
s.class(pca.stt$li, pop(stt), xax=3, yax=4, # define PCA, population splits, and axes to plot
        col=transp(c("darkgoldenrod3", "chartreuse4"),.6), # colors
        axesell=F, cstar=0, grid=F, #cellipse = 1, # plot grid and basics, no lines connecting to centroid, no ellipse
        cpoint=2, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        sub="PCs 3,4", csub = 1.5, possub = "topright" # title
        )
#Fig3
tiff("PCA.stt.tif", width = 900, height = 900)
s.class(pca.stt$li, pop(stt), xax=1, yax=2, # define PCA, population splits, and axes to plot
        col=transp(c(pal[1:2]),.6), # colors
        axesell=F, cstar=0, grid=F, cellipse = 0, clabel = 2,#clabel = F, # plot grid and basics, no lines connecting to centroid, no group labels
        cpoint=4, pch = c(rep(18, 44), rep(20, 34)), # symbol type and size
        )
        mtext("PC 1: 6.8% variance", side = 1, padj = 3, font = 2, at = 7, cex = 2) # horizontal axis label
        mtext("PC 2: 4.7% variance", side = 2, padj = -1.7, font = 2, at = -4, cex = 2) # vertical axis label
dev.off()

#################
## Mantel Test ##
#################

# Run Mantel test for isolation by distance, following the "basics" tutorial here: https://github.com/thibautjombart/adegenet/wiki/Tutorials
# these files formatted in file conversion script

# read in locality data
data.loca <- read.csv("genotyped samples localities.csv", header = T, na.strings = "")
str(data.loca)
# trim location data file to only samples with location data
data.loca2 <- data.loca[complete.cases(data.loca[,2:3]),]
str(data.loca2)
data.loca3 <- data.loca2[,1:3]
str(data.loca3)
row.names(data.loca3) <- data.loca3$ID

#reformat to package requirements
colnames(data.loca3)<-c("ID", "Y", "X")
#Convert to UTM coordinates - SPCA will not take the raw long/lat
attr(data.loca3, "projection") <- "LL"
str(data.loca3)
UTMcoords <- convUL(data.loca3) #check UTM zone detection to be sure it's correct. My data from UTM Zone 14

# generate dist matrices
# get genetic distances
loc.genind <- read.genepop("genepop_input_samples_with_locality_info.gen", ncode = 2, quiet = F)
Dgen <- dist(loc.genind$tab)
str(Dgen)
# get geographic distances
Dgeo <- dist(UTMcoords)
str(Dgeo)

#Run the MC-based Mantel test:
ibd <- mantel.randtest(Dgen,Dgeo, nrepet = 9999)
ibd
pdf(file="IBD p value.pdf", width=5, height=5)
        plot(ibd)
dev.off()

#IBD plot
dens <- kde2d(Dgeo,Dgen, n=300)
myPal <- colorRampPalette(c("white","blue","gold", "orange", "red"))
pdf(file="IBD plot all individuals.pdf", width=5, height=5)
        plot(Dgeo, Dgen, pch=20,cex=.5, xlab="Geographic distance (km)", ylab="Genetic distance")
        image(dens, col=transp(myPal(300),.7), add=TRUE)
dev.off()

#END
