setwd("/scratch/snyder/b/bylsma/massasauga/genome_alignment/")

install.packages("ape", lib="/scratch/snyder/b/bylsma/massasauga/genome_alignment/rlibs/", repos='http://cran.us.r-project.org')
.libPaths("/scratch/snyder/b/bylsma/massasauga/genome_alignment/rlibs") 

library(ape)
alignments = read.table("alignments_list.txt", sep="\t")
colnames(alignments) = c("sp1_sp2")

#iterate over alignments list and estimate divergence
write.table(t(c("spp", "length", "raw", "K80", "K81", "F84", "TN93")), "DNAdiv_estimates.csv", sep=",", row.names=F, col.names=F, append=F)
write.table(t(c("starting loop")), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=F)
for(f in 1:nrow(alignments)){
  # read in each data file
  data = read.table(paste(alignments$sp1_sp2[f]), sep="\t", header=T)
  colnames(data) = c("qseqid", "sseqid", "length", "evalue", "pident", "nident", "mismatch", "gapopen", "gaps", "qstart", "qend", "qlen", "sstart", "send", "slen", "score", "bitscore", "qseq", "sseq")
  # remove alignments less than 2000bp
  tdata <- data[!(data$length<2000),]
  data = tdata
  # print summary statistics to stdout
  print(paste("alignment: ", alignments$sp1_sp2[f]))
  idPct <- as.numeric(sub("%", "", data$pident, fixed = T))/100
  print(paste("ID percent mean: ", mean(idPct)))
  print(paste("ID percent sd: ", sd(idPct)))
  print(paste("Length sum: ", sum(data$length)))
  print(paste("Length mean: ", mean(data$length)))
  print(paste("Length sd: ", sd(data$length)))

  #sub-sample if number of sites greater than upper limit
  limit = (2^31-1)/2  #this could be run again with smallest length value across all species pairs
  if(sum(data$length)>limit){
    tokeep = sample(seq(1,nrow(data)), limit/1000, replace=F)
    tdata = data[tokeep,]
    while(sum(tdata$length)>limit){
      tokeep = sample(seq(1,nrow(tdata)), (nrow(tdata)-1), replace=F)
      tdata = tdata[tokeep,]
    }
    data = tdata
  }
  
  #prep aligned sequences
  s = strsplit(paste(data$sseq, "", collapse=""), "")
  q = strsplit(paste(data$qseq, "", collapse=""), "")
  
  temp = as.DNAbin(c(s, q))
  write.table(paste("created DNAbin for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)
  
  #estimate divergences
  raw = K80 = K81 = F84 = TN93 = NULL
  raw = dist.dna(temp, model=c("raw"), variance = T)
  K80 = dist.dna(temp, model=c("K80"), variance = T)
  K81 = dist.dna(temp, model=c("K81"), variance = T)
  F84 = dist.dna(temp, model=c("F84"), variance = T)
  TN93 = dist.dna(temp, model=c("TN93"), variance = T)
  cat(str(K80)); cat(str(K81)); cat(str(raw)); cat(str(F84)); cat(str(TN93))
  write.table(paste("Finished total calculations for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)
  
  #save output
  write.table(t(c(as.character(alignments$sp1_sp2[f]), summary(temp)[1,1], raw, K80, K81, F84, TN93)), "DNAdiv_estimates.csv", sep=",", row.names=F, col.names=F, append=T)

  # run separately for all aligned sequences
  write.table(t(c("q_scaffold", "s_scaffold", "length", "q_length", "s_length", "aligned_length", "raw", "K80", "K81", "F84", "TN93")), paste("DNAdiv_sequences_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=F)
  # run estimates for each row
  for(j in 1:nrow(data)){
    #prep aligned sequences
    s = strsplit(paste(data$sseq[j], "", collapse=""), "")
    q = strsplit(paste(data$qseq[j], "", collapse=""), "")
    
    temp = as.DNAbin(c(s, q))
    
    #estimate divergences
    raw = K80 = K81 = F84 = TN93 = NULL
    raw = dist.dna(temp, model=c("raw"))
    K80 = dist.dna(temp, model=c("K80"))
    K81 = dist.dna(temp, model=c("K81"))
    F84 = dist.dna(temp, model=c("F84"))
    TN93 = dist.dna(temp, model=c("TN93"))
    
    #save output
    write.table(t(c(data$qseqid[j], data$sseqid[j], data$length[j], data$qlen[j], data$slen[j], summary(temp)[1,1], raw, K80, K81, F84, TN93)), paste("DNAdiv_sequences_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=T)
  }
  write.table(paste("Finished per sequence calculations for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)
  # run separately for all scaffolds
  # identify all scaffolds for both genomes
  qscaffs <- unique(data$qseqid)
  sscaffs <- unique(data$sseqid)
  write.table(t(c("s_scaffold", "length", "s_length", "q_length", "aligned_length", "raw", "K80", "K81", "F84", "TN93")), paste("DNAdiv_Sscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=F)
  for(r in 1:length(sscaffs)){
    # prep scaffolded sequences
    s = strsplit(paste(data[data$sseqid %in% sscaffs[r],(ncol(data)-0)], "", collapse=""), "")
    q = strsplit(paste(data[data$sseqid %in% sscaffs[r],(ncol(data)-1)], "", collapse=""), "")
    
    temp = as.DNAbin(c(s, q))
    
    #estimate divergences
    raw = K80 = K81 = F84 = TN93 = NULL
    raw = dist.dna(temp, model=c("raw"))
    K80 = dist.dna(temp, model=c("K80"))
    K81 = dist.dna(temp, model=c("K81"))
    F84 = dist.dna(temp, model=c("F84"))
    TN93 = dist.dna(temp, model=c("TN93"))

    #save output
    write.table(t(c(sscaffs[r], sum(data[data$sseqid %in% sscaffs[r],3]), sum(data[data$sseqid %in% sscaffs[r],15]), sum(data[data$sseqid %in% sscaffs[r],12]), summary(temp)[1,1], raw, K80, K81, F84, TN93)), paste("DNAdiv_Sscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=T)
  }
  write.table(paste("Finished s per scaffold calculations for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)
  write.table(t(c("q_scaffold", "length", "q_length", "s_length", "aligned_length", "raw", "K80", "K81", "F84", "TN93")), paste("DNAdiv_Qscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=F)
  for(p in 1:length(qscaffs)){
    # prep scaffolded sequences
    s = strsplit(paste(data[data$qseqid %in% qscaffs[p],(ncol(data)-0)], "", collapse=""), "")
    q = strsplit(paste(data[data$qseqid %in% qscaffs[p],(ncol(data)-1)], "", collapse=""), "")
    
    temp = as.DNAbin(c(s, q))
    
    #estimate divergences
    raw = K80 = K81 = F84 = TN93 = NULL
    raw = dist.dna(temp, model=c("raw"))
    K80 = dist.dna(temp, model=c("K80"))
    K81 = dist.dna(temp, model=c("K81"))
    F84 = dist.dna(temp, model=c("F84"))
    TN93 = dist.dna(temp, model=c("TN93"))
    
    #save output
    write.table(t(c(qscaffs[p], sum(data[data$qseqid %in% qscaffs[p],3]), sum(data[data$qseqid %in% qscaffs[p],12]), sum(data[data$qseqid %in% qscaffs[p],15]), summary(temp)[1,1], raw, K80, K81, F84, TN93)), paste("DNAdiv_Qscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=T)
  }
  write.table(paste("Finished q per scaffold calculations for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)
  # read back in distances per sequence and scaffold
  dist.seq <- read.csv(paste("DNAdiv_sequences_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), header = T)
  dist.sscaff <- read.csv(paste("DNAdiv_Sscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), header = T)  
  dist.qscaff <- read.csv(paste("DNAdiv_Qscaffolds_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), header = T)
  print(paste("sequence mean/sd", as.character(alignments$sp1_sp2[f]), " : ",
        mean(dist.seq$K80), "+-",
        sd(dist.seq$K80)))
  print(paste("S scaffold mean/sd", as.character(alignments$sp1_sp2[f]), " : ",
        mean(dist.sscaff$K80), "+-",
        sd(dist.sscaff$K80)))
  print(paste("Q scaffold mean/sd", as.character(alignments$sp1_sp2[f]), " : ",
        mean(dist.qscaff$K80), "+-",
        sd(dist.qscaff$K80)))
  # plot K80 distances by sequences and scaffolds
  tiff(paste("length_by_K80_", as.character(alignments$sp1_sp2[f]), ".tiff", sep = ""), width = 1200, height = 400)
    par(mfrow=c(1,3))
    plot(dist.seq$aligned_length, dist.seq$K80, main = "Sequences", pch = 19, col = "darkgreen", xlab = "length", ylab = "K80")
    plot(dist.sscaff$aligned_length, dist.sscaff$K80, main = "S scaffolds", pch = 19, col = "darkgreen", xlab = "length", ylab = "K80")
    plot(dist.qscaff$aligned_length, dist.qscaff$K80, main = "Q scaffolds", pch = 19, col = "darkgreen", xlab = "length", ylab = "K80")
  dev.off()
}

#END