# format_conversion_scripts.R
# To convert SNP genotype from Call Map files to genepop format
# to convert genepop file to STRUCTURE file (using PGDspideR() from genepopedit package)
library(genepopedit)

# == Call map (.csv) -> genepop (.gen/.txt) == #
#-----------------------------------------------------------
# The Input File Format for Genepop(WWW) and LinkDos(WWW) :
# First line : Any characters. Use this line to store information about you data.
# Second line : the name of the first locus. 
# Third line : the name of the second locus (if needed) 
# ETC...

# Alternatively, separate loci with commas (or a comma+space) on the same line.
# Line N+1 : the name of the Nth locus. 
# Line N+2 : Type the word "POP" (or "Pop", or "pop"). 
# Line N+3 : And example is given below :

#  ind#001fem, 0101 0202 0000 0410
#-----------------------------------------------------------

# first, sort genotyping files by population

#setwd("D:/DeWoody Lab/Massasauga Rattlesnakes/scripts and outputs/")
setwd("C:/Users/Rian/Desktop/scripts and outputs/")

# load genotyping files
data.all <- read.csv("Genotyping results_all.csv")
data.neu <- read.csv("Genotyping results_neu.csv")
data.adap <- read.csv("Genotyping results_adap.csv")
data.ste <- read.csv("Genotyping results_ste.csv")
data.stt <- read.csv("Genotyping results_stt.csv")
data.ste.neu <- read.csv("Genotyping results_ste_neu.csv")
data.ste.adap <- read.csv("Genotyping results_ste_adap.csv")
data.stt.neu <- read.csv("Genotyping results_stt_neu.csv")
data.stt.adap <- read.csv("Genotyping results_stt_adap.csv")
data.w.locality <- read.csv("Genotyping results_all.csv")
data.ade <- read.csv("Genotyping results_ade.csv") # non-HWE loci removed
str(data.all)
str(data.neu)
str(data.adap)
str(data.ste)
str(data.stt)
str(data.ste.neu)
str(data.ste.adap)
str(data.stt.neu)
str(data.stt.adap)
str(data.ade)

# define special character values:
all.loci_w.outgroups <- "genepop_input_all.txt"
  all.loci_outgroups_str <- "structure_input_all_R.txt"
  all.loci_w.outgroups_ade <- "adegenet_input_all.txt"
all.loci_no.outgroups <- "genepop_input_western.txt"
  all.loci_no.outgroups_str <- "structure_input_western_R.txt"
  all.loci_no.outgroups_ade <- "adegenet_input_western.txt"
neu.loci_w.outgroups <- "genepop_input_all_neu.txt"
neu.loci_no.outgroups <- "genepop_input_western_neu.txt"
adap.loci_w.outgroups <- "genepop_input_all_adap.txt"
adap.loci_no.outgroups <- "genepop_input_western_adap.txt"
ste.loci_w.outgroups <- "genepop_input_all_ste.txt"
ste.loci_no.outgroups <- "genepop_input_western_ste.txt"
stt.loci_w.outgroups <- "genepop_input_all_stt.txt"
stt.loci_no.outgroups <- "genepop_input_western_stt.txt"
ste.neu_w.outgroups <- "genepop_input_all_ste_neu.txt"
ste.neu_no.outgroups <- "genepop_input_western_ste_neu.txt"
ste.adap_w.outgroups <- "genepop_input_all_ste_adap.txt"
ste.adap_no.outgroups <- "genepop_input_western_ste_adap.txt"
stt.neu_w.outgroups <- "genepop_input_all_stt_neu.txt"
stt.neu_no.outgroups <- "genepop_input_western_stt_neu.txt"
stt.adap_w.outgroups <- "genepop_input_all_stt_adap.txt"
stt.adap_no.outgroups <- "genepop_input_western_stt_adap.txt"
samples.with.locality <- "genepop_input_samples_with_locality_info.txt"

cat("Western Massasauga Genotypes w/ outgroups, all loci\n", file = all.loci_w.outgroups)
cat(colnames(data.all[2:172]),"\n", file = all.loci_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, all loci\n", file = all.loci_no.outgroups)
cat(colnames(data.all[2:172]),"\n", file = all.loci_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.all)) 
{
  name <- as.character(data.all[s,1])
  genotype <- as.character.numeric_version(data.all[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = all.loci_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = all.loci_no.outgroups, append = T)
}

# Neutral Loci

cat("Western Massasauga Genotypes w/ outgroups, neutral loci\n", file = neu.loci_w.outgroups)
cat(colnames(data.neu[2:84]),"\n", file = neu.loci_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, neutral loci\n", file = neu.loci_no.outgroups)
cat(colnames(data.neu[2:84]),"\n", file = neu.loci_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.neu)) 
{
  name <- as.character(data.neu[s,1])
  genotype <- as.character.numeric_version(data.neu[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = neu.loci_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = neu.loci_no.outgroups, append = T)
}

# Adaptive Loci

cat("Western Massasauga Genotypes w/ outgroups, adaptive loci\n", file = adap.loci_w.outgroups)
cat(colnames(data.adap[2:89]),"\n", file = adap.loci_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, adaptive loci\n", file = adap.loci_no.outgroups)
cat(colnames(data.adap[2:89]),"\n", file = adap.loci_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.adap)) 
{
  name <- as.character(data.adap[s,1])
  genotype <- as.character.numeric_version(data.adap[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = adap.loci_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = adap.loci_no.outgroups, append = T)
}

# Loci from Desert

cat("Western Massasauga Genotypes w/ outgroups, Desert loci\n", file = ste.loci_w.outgroups)
cat(colnames(data.ste[2:79]),"\n", file = ste.loci_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Desert loci\n", file = ste.loci_no.outgroups)
cat(colnames(data.ste[2:79]),"\n", file = ste.loci_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.ste)) 
{
  name <- as.character(data.ste[s,1])
  genotype <- as.character.numeric_version(data.ste[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = ste.loci_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = ste.loci_no.outgroups, append = T)
}

cat("Western Massasauga Genotypes w/ outgroups, Neutral Desert loci\n", file = ste.neu_w.outgroups)
cat(colnames(data.ste.neu[2:39]),"\n", file = ste.neu_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Neutral Desert loci\n", file = ste.neu_no.outgroups)
cat(colnames(data.ste.neu[2:39]),"\n", file = ste.neu_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.ste.neu)) 
{
  name <- as.character(data.ste.neu[s,1])
  genotype <- as.character.numeric_version(data.ste.neu[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = ste.neu_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = ste.neu_no.outgroups, append = T)
}

cat("Western Massasauga Genotypes w/ outgroups, Adaptive Desert loci\n", file = ste.adap_w.outgroups)
cat(colnames(data.ste.adap[2:41]),"\n", file = ste.adap_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Adaptive Desert loci\n", file = ste.adap_no.outgroups)
cat(colnames(data.ste.adap[2:41]),"\n", file = ste.adap_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.ste.adap)) 
{
  name <- as.character(data.ste.adap[s,1])
  genotype <- as.character.numeric_version(data.ste.adap[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = ste.adap_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = ste.adap_no.outgroups, append = T)
}

# Loci from Prairie

cat("Western Massasauga Genotypes w/ outgroups, Prairie loci\n", file = stt.loci_w.outgroups)
cat(colnames(data.stt[2:94]),"\n", file = stt.loci_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Prairie loci\n", file = stt.loci_no.outgroups)
cat(colnames(data.stt[2:94]),"\n", file = stt.loci_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.stt)) 
{
  name <- as.character(data.stt[s,1])
  genotype <- as.character.numeric_version(data.stt[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = stt.loci_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = stt.loci_no.outgroups, append = T)
}

cat("Western Massasauga Genotypes w/ outgroups, Neutral Prairie loci\n", file = stt.neu_w.outgroups)
cat(colnames(data.stt.neu[2:46]),"\n", file = stt.neu_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Neutral Prairie loci\n", file = stt.neu_no.outgroups)
cat(colnames(data.stt.neu[2:46]),"\n", file = stt.neu_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.stt.neu)) 
{
  name <- as.character(data.stt.neu[s,1])
  genotype <- as.character.numeric_version(data.stt.neu[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = stt.neu_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = stt.neu_no.outgroups, append = T)
}

cat("Western Massasauga Genotypes w/ outgroups, Adaptive Prairie loci\n", file = stt.adap_w.outgroups)
cat(colnames(data.stt.adap[2:49]),"\n", file = stt.adap_w.outgroups, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, Adaptive Prairie loci\n", file = stt.adap_no.outgroups)
cat(colnames(data.stt.adap[2:49]),"\n", file = stt.adap_no.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.stt.adap)) 
{
  name <- as.character(data.stt.adap[s,1])
  genotype <- as.character.numeric_version(data.stt.adap[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = stt.adap_w.outgroups, append = T)
  cat(name,",", genotype, "\n", file = stt.adap_no.outgroups, append = T)
}

# For adegenet DAPC. Removed all non-HWE loci (see genepop_analysis.R)
  # for use after genepop_analysis.R script to remove loci out of HWE
cat("Western Massasauga Genotypes w/ outgroups, all loci -- for adegenet DAPC\n", file = all.loci_w.outgroups_ade)
cat(colnames(data.ade[2:140]),"\n", file = all.loci_w.outgroups_ade, sep = ",", append= TRUE)
cat("Western Massasauga Genotypes w/o outgroups, all loci -- for adegenet DAPC\n", file = all.loci_no.outgroups_ade)
cat(colnames(data.ade[2:140]),"\n", file = all.loci_no.outgroups_ade, sep = ",", append= TRUE)

for (s in 1:nrow(data.ade)) 
{
  name <- as.character(data.ade[s,1])
  genotype <- as.character.numeric_version(data.ade[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = all.loci_w.outgroups_ade, append = T)
  cat(name,",", genotype, "\n", file = all.loci_no.outgroups_ade, append = T)
}

# SNP data for samples with geocoordinates (locality data)
# load location data file
  locality <- read.csv("genotyped samples localities.csv", header = T, na.strings = "")
  # trim location file to samples with location data and change row names
  locality <- locality[,1:3]
  locality <- locality[complete.cases(locality[,2:3]),]
  row.names(locality) <- locality$ID
  row.names(data.w.locality) <- data.w.locality$..Sample
# trim genotype file to samples with location data
needed <- which(rownames(data.w.locality) %in% rownames(locality))
data.w.locality <- data.w.locality[needed,]

cat("Western Massasauga Genotypes, Samples with locality data\n", file = samples.with.locality)
cat(colnames(data.w.locality[2:172]),"\n", file = samples.with.locality, sep = ",", append= TRUE)

for (s in 1:nrow(data.w.locality)) 
{
  name <- as.character(data.w.locality[s,1])
  genotype <- as.character.numeric_version(data.w.locality[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  genotype <- gsub(':','',genotype)
  cat(name,",", genotype, "\n", file = samples.with.locality, append = T)
}

# manually split by populations: insert line "pop\n" between populations
# manually remove outgroup samples from genepop files that shouldn't have them.
# manually delete last comma (separator) in list of loci (header row)


# == genepop -> STRUCTURE == #
## (!) need java in R to make this run. Wasn't worth the time. (!) Just used PGDspider GUI. 
#PGDspideR(all.loci_w.outgroups, "genepop", all.loci_outgroups_str, "structure", where.pgdspider = "PGDSpider_2.1.1.5", spid = "PGDSpider_2.1.1.5/GENEPOP_to_STRUCTURE.spid")

#END

data.west <- read.csv("Genotyping results Western.csv")
for.heterozygosity <- "western_heterozygosity.csv"
cat("Western Massasauga Genotypes w/ outgroups, all loci\n", file = all.loci_w.outgroups)
cat(colnames(data.west[2:179]),"\n", file = all.loci_w.outgroups, sep = ",", append= TRUE)

for (s in 1:nrow(data.all)) 
{
  name <- as.character(data.all[s,1])
  genotype <- as.character.numeric_version(data.all[s,-1])
  genotype <- gsub('No Call','0000',genotype)
  genotype <- gsub('A','01',genotype)
  genotype <- gsub('C','02',genotype)
  genotype <- gsub('G','03',genotype)
  genotype <- gsub('T','04',genotype)
  cat(name,",", genotype, "\n", file = all.loci_no.outgroups, append = T)
}
