# genepop_analysis.R
# Identifying allele frequencies, deviation from H-W, LD in Western Massasauga SNP Genotype data

library(genepop)

#setwd("D:/DeWoody Lab/Massasauga Rattlesnakes/scripts and outputs/")
setwd("C:/Users/Rian/Desktop/scripts and outputs/")

# To calculate LD

test_LD("genepop_input_western.txt", outputFile = "genepop_LD_western.txt",
        dememorization = 10000, batches = 20, iterations = 5000)
write_LD_tables("genepop_input_western.txt", outputFile = "genepop_LD_table_western.txt")

# Holmes-Bonferroni corrections - LD
  # extract p-values from LD output
  # copy table portion of LD_test output for all individuals as a single population into excel, text to columns function based on fixed width
  # remove ---- row after header row
my.ld <- read.csv("ld_p.csv", na.strings = c("Not possib", "le", ""))
str(my.ld)
View(my.ld)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate LD. This test is conservative)
my.ld$P.bonferroni <- p.adjust(my.ld$P.val, method = "holm", length(my.ld$P.val))
str(my.ld)
# identify bonferroni-significant LD
loci.to.remove <- my.ld[which(my.ld$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(loci.to.remove, file = "LD_loci_to_remove.csv")

# Removed minimum number of loci (13) to avoid LD after bonferroni correction. Then, recreated genepop files.
# Had to copy all .gen files and change extension to .txt

# To calculate He, Ho, MAF, Fis

basic_info("genepop_input_all.txt", outputFile ="genepop_basicinfo_all.txt")
basic_info("genepop_input_western.txt", outputFile ="genepop_basicinfo_western.txt")
basic_info("genepop_input_western_neu.txt", outputFile ="genepop_basicinfo_western_neu.txt")
basic_info("genepop_input_western_adap.txt", outputFile ="genepop_basicinfo_all_western_adap.txt")
basic_info("genepop_input_all_neu.txt", outputFile ="genepop_basicinfo_all_neu.txt")
basic_info("genepop_input_all_adap.txt", outputFile ="genepop_basicinfo_all_adap.txt")
basic_info("genepop_input_all_ste.txt", outputFile ="genepop_basicinfo_all_ste.txt")
basic_info("genepop_input_all_stt.txt", outputFile ="genepop_basicinfo_all_stt.txt")
basic_info("genepop_input_western_ste.txt", outputFile ="genepop_basicinfo_western_ste.txt")
basic_info("genepop_input_western_stt.txt", outputFile ="genepop_basicinfo_western_stt.txt")
basic_info("genepop_input_all_ste_neu.txt", outputFile ="genepop_basicinfo_all_ste_neu.txt")
basic_info("genepop_input_all_stt_neu.txt", outputFile ="genepop_basicinfo_all_stt_neu.txt")
basic_info("genepop_input_western_ste_neu.txt", outputFile ="genepop_basicinfo_western_ste_neu.txt")
basic_info("genepop_input_western_stt_neu.txt", outputFile ="genepop_basicinfo_western_stt_neu.txt")
basic_info("genepop_input_all_ste_adap.txt", outputFile ="genepop_basicinfo_all_ste_adap.txt")
basic_info("genepop_input_all_stt_adap.txt", outputFile ="genepop_basicinfo_all_stt_adap.txt")
basic_info("genepop_input_western_ste_adap.txt", outputFile ="genepop_basicinfo_western_ste_adap.txt")
basic_info("genepop_input_western_stt_adap.txt", outputFile ="genepop_basicinfo_western_stt_adap.txt")


# To Test for Hardy-Weinberg genotypic proportions
# I did these tests with Desert/Prairie split and as one population

# using probabilities
test_HW("genepop_input_western.txt", which = "Proba", outputFile = "genepop_HW_western.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)
test_HW("genepop_input_western_onepop.txt", which = "Proba", outputFile = "genepop_HW_western_onepop.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)

# heterozygote excess
test_HW("genepop_input_western.txt", which = "excess", outputFile = "genepop_Het_excess_western.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)
test_HW("genepop_input_western_onepop.txt", which = "excess", outputFile = "genepop_Het_excess_western_onepop.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)

# heterozygote deficit
test_HW("genepop_input_western.txt", which = "deficit", outputFile = "genepop_Het_deficit_western.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)
test_HW("genepop_input_western_onepop.txt", which = "deficit", outputFile = "genepop_Het_deficit_western_onepop.txt",
        enumeration = FALSE, dememorization = 10000, batches = 20,
        iterations = 5000)

# Holmes-Bonferroni corrections - HWP, Het excess, Het deficit
  # extract p-values from genepop output:
  # open table portion of HW_test output for all individuals as a single population into excel, based on spaces as delimitation
  # remove excess rows (i.e. keep only header row and data)
my.hw <- read.csv("genepop_HW_western.csv", na.strings = c("No", "information.", ""))
str(my.hw)
View(my.hw)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.hw$P.bonferroni <- p.adjust(my.hw$P.val, method = "holm", length(my.hw$P.val))
str(my.hw)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.hw[which(my.hw$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.hw, file = "genepop_HW_western.csv")
write.csv(loci.to.remove, file = "HWP_loci_to_remove.csv")

my.hwo <- read.csv("genepop_HW_western_onepop.csv", na.strings = c("No", "information.", "", "NA"))
str(my.hwo)
View(my.hwo)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.hwo$P.bonferroni <- p.adjust(my.hwo$P.val, method = "holm", length(my.hwo$P.val))
str(my.hwo)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.hwo[which(my.hwo$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.hwo, file = "genepop_HW_western_onepop.csv")
write.csv(loci.to.remove, file = "HWP_loci_to_remove_onepop.csv")

# create excel dataframe w/o non-HWE loci
data.all <- read.csv("Genotyping results_all.csv")
str(data.all)
dim(data.all)
loci.to.remove[,1]
data.hwe <- data.all[ , -which(names(data.all) %in% loci.to.remove[,1])]
str(data.hwe)
dim(data.hwe)
# check that it worked properly, columns in data.all - rows in loci.to.remove = columns in data.hwe
dim(data.all) # second number
dim(loci.to.remove) # first number
dim(data.hwe) # second number
# if these numbers match (all-loci=hwe), simple check to if correct columns were removed
which(names(data.hwe) %in% loci.to.remove[,1]) # should be zero
# write to .csv so it can be saved and also converted to .gen file (format conversion scripts.R) for use in adegenet DAPC analysis
write.csv(data.hwe, "Genotyping results_ade.csv", row.names = F)

my.he <- read.csv("genepop_Het_excess_western.csv", na.strings = c("No", "information.", ""))
str(my.he)
View(my.he)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.he$P.bonferroni <- p.adjust(my.he$P.val, method = "holm", length(my.he$P.val))
str(my.he)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.he[which(my.he$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.he, file = "genepop_Het_excess_western.csv")
write.csv(loci.to.remove, file = "Het_excess_loci.csv")

my.heo <- read.csv("genepop_Het_excess_western_onepop.csv", na.strings = c("No", "information.", ""))
str(my.heo)
View(my.heo)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.heo$P.bonferroni <- p.adjust(my.heo$P.val, method = "holm", length(my.heo$P.val))
str(my.heo)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.heo[which(my.heo$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.heo, file = "genepop_Het_excess_western_onepop.csv")
write.csv(loci.to.remove, file = "Het_excess_loci_onepop.csv")

my.hd <- read.csv("genepop_Het_deficit_western.csv", na.strings = c("No", "information.", ""))
str(my.hd)
View(my.hd)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.hd$P.bonferroni <- p.adjust(my.hd$P.val, method = "holm", length(my.hd$P.val))
str(my.hd)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.hd[which(my.hd$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.hd, file = "genepop_Het_deficit_western.csv")
write.csv(loci.to.remove, file = "Het_deficit_loci.csv")

my.hdo <- read.csv("genepop_Het_deficit_western_onepop.csv", na.strings = c("No", "information.", ""))
str(my.hdo)
View(my.hdo)
# p-value correction (this is a Sequential Bonferroni Correction to conservatively evaluate which significant deviations from HWE are by chance which are likely to be true devations. This test is conservative)
my.hdo$P.bonferroni <- p.adjust(my.hdo$P.val, method = "holm", length(my.hdo$P.val))
str(my.hdo)
# identify bonferroni-significant loci deviating from HWE
loci.to.remove <- my.hdo[which(my.hdo$P.bonferroni < 0.05),]
length(loci.to.remove[,1])
write.csv(my.hdo, file = "genepop_Het_deficit_western_onepop.csv")
write.csv(loci.to.remove, file = "Het_deficit_loci_onepop.csv")

# Fst estimation

Fst("genepop_input_all.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all.txt",
    dataType = "Diploid")
Fst("genepop_input_western.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western.txt",
    dataType = "Diploid")
Fst("genepop_input_western_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_western_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_adap.txt",
    dataType = "Diploid")
Fst("genepop_input_all_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_all_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_adap.txt",
    dataType = "Diploid")
Fst("genepop_input_all_ste.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_ste.txt",
    dataType = "Diploid")
Fst("genepop_input_all_stt.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_stt.txt",
    dataType = "Diploid")
Fst("genepop_input_western_ste.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_ste.txt",
    dataType = "Diploid")
Fst("genepop_input_western_stt.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_stt.txt",
    dataType = "Diploid")
Fst("genepop_input_all_ste_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_ste_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_all_stt_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_stt_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_western_ste_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_ste_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_western_stt_neu.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_stt_neu.txt",
    dataType = "Diploid")
Fst("genepop_input_all_ste_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_ste_adap.txt",
    dataType = "Diploid")
Fst("genepop_input_all_stt_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_all_stt_adap.txt",
    dataType = "Diploid")
Fst("genepop_input_western_ste_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_ste_adap.txt",
    dataType = "Diploid")
Fst("genepop_input_western_stt_adap.txt", sizes = FALSE, pairs = TRUE, outputFile = "genepop_Fst_western_stt_adap.txt",
    dataType = "Diploid")
# calculate standard deviations for Fst using values for individual loci
my.fst <- read.csv("fst.csv", header = T, na.strings = c("-", "")) # a spreadsheet with 10 columns: locus, fst value (all, intergenic, genic, desert, prairie, intergenic_desert, genic_desert, intergenic_prairie, genic_prairie)
str(my.fst)
sd(my.fst$all, na.rm = T)
sd(my.fst$hwe, na.rm = T)
sd(my.fst$intergenic, na.rm = T)
sd(my.fst$genic, na.rm = T)
sd(my.fst$desert, na.rm = T)
sd(my.fst$prairie, na.rm = T)
sd(my.fst$intergenic.desert, na.rm = T)
sd(my.fst$genic.desert, na.rm = T)
sd(my.fst$intergenic.prairie, na.rm = T)
sd(my.fst$genic.prairie, na.rm = T)

# get estimate of average Fst values within Desert and within Prairie (using adegenet and hierfstat)
library(adegenet)
library(hierfstat)


# forloop to get spreadsheet of all data subsets
# load in list of data subsets
genotype.files = read.table("genotype_files_for_Fst.list", sep="\t") # this list contains the names of files breaking down SNP genotypes into data subsets. (ej. intergenic SNPs, SNPs from Desert representative, etc. See paper for details)
colnames(genotype.files) = c("subset")
# write list of populations
pop_list <- c("desert", "prairie")
# define number of runs
n.runs <- 500
# create output dataframe for all runs
fst_runs <- data.frame(matrix(NA, ncol = nrow(genotype.files)*length(pop_list), nrow = n.runs))
#iterate over files list and calculate multiple runs of Fst
for(i in 1:nrow(genotype.files)){
  # read in genepop file with all populations using adegenet
  my.genind <- read.genepop(paste("adegenet_input_western_", genotype.files[i,], "_heterozygosity.gen", sep = ""), ncode = 2, quiet = F)
  #View(my.genind)
  #str(my.genind)
  # change names of populations
  levels(my.genind$pop) <- c("desert","prairie")
  #str(my.genind)
  for (r in 1:n.runs) {
    for (p in 1:length(pop_list)){
      # label column current column
      colnames(fst_runs)[i*length(pop_list)-length(pop_list)+p] <- noquote(paste(genotype.files[i,], "_", pop_list[p], sep = ""))
      # generate random population assignments for each population
      rand_pops <- sample(1:2, sum(my.genind$pop == pop_list[p]), replace=TRUE)
      # calculate Fst for random division of each population
      fst <- fstat(my.genind[my.genind@pop == pop_list[p]], pop = rand_pops, fstonly = T)
      fst_runs[r, i*length(pop_list)-length(pop_list)+p] <- fst
    }
  }
}
write.csv(fst_runs, file = "fst_runs.csv", quote = F)
# get summary statistics
# list of desired statistics
stat_list <- c("mean", "sd","min", "max", "median", "n.runs")
fst_table <- data.frame(matrix(NA, nrow = ncol(fst_runs), ncol = length(stat_list)))
rownames(fst_table) <- colnames(fst_runs)
colnames(fst_table) <- stat_list
for (s in 1:ncol(fst_runs)){
    fst_table$mean[s] <- mean(fst_runs[,s])
    fst_table$sd[s] <- sd(fst_runs[,s])
    fst_table$min[s] <- min(fst_runs[,s])
    fst_table$max[s] <- max(fst_runs[,s])
    fst_table$median[s] <- median(fst_runs[,s])
    fst_table$n.runs[s] <- length(fst_runs[is.na(fst_runs[,s]) == F, s])
}
write.csv(fst_table, file = "fst_table.csv", quote = F)

# verify that randomized population assignment is approximately even
rand_trial <- matrix(NA, nrow = 504, ncol = 52)
for(t in 1:500){
  rand_trial[t,1:50] <- sample(1:2, 50, replace=TRUE)
  rand_trial[t,51] <- sum(rand_trial[t,1:50] == 1)
  rand_trial[t,52] <- sum(rand_trial[t,1:50] == 2)
}
rand_trial[501,50:52] <- c("mean", mean(rand_trial[1:500,51]), mean(rand_trial[1:500,52]))
rand_trial[502,50:52] <- c("sd", sd(rand_trial[1:500,51]), sd(rand_trial[1:500,52]))
rand_trial[503,50:52] <- c("min", min(rand_trial[1:500,51]), min(rand_trial[1:500,52]))
rand_trial[504,50:52] <- c("max", max(rand_trial[1:500,51]), max(rand_trial[1:500,52]))

# runs for both subspecies with randomized populations
rand_pops <- matrix(NA, nrow = 504, ncol = 79)
for(t in 1:500){
  rand_pops[t,1:78] <- sample(1:2, 78, replace=TRUE)
  # calculate Fst for random division of each population
  fst <- fstat(my.genind, pop = rand_pops[t, 1:78], fstonly = T)
  rand_pops[t,79] <- fst
}
rand_pops[501,78:79] <- c("mean", mean(rand_pops[1:500,79]))
rand_pops[502,78:79] <- c("sd", sd(rand_pops[1:500,79]))
rand_pops[503,78:79] <- c("min", min(rand_pops[1:500,79]))
rand_pops[504,78:79] <- c("max", max(rand_pops[1:500,79]))
write.csv(rand_pops, file = "fst_runs_desertandprairielumped.csv", quote = F)


#END
