#All blast output files were obtained from Rian on 9/24 and are located at the following path:
pwd
#/scratch/snyder/b/blackan/forblack2

#And the files used as input
ls -1 BLAST*100kb.txt
#BLAST_cvir_scat_100kb.txt
#BLAST_cvir_ste_100kb.txt
#BLAST_cvir_stt_100kb.txt
#BLAST_scat_ste_100kb.txt
#BLAST_scat_stt_100kb.txt
#BLAST_stt_ste_100kb.txt


#Using each file, the relevant columns were extracted. For example:
awk '{print $1,$2,$18,$19}' BLAST_cvir_scat_100kb.txt > to.parse

#Each row from the blast output file was then parsed out into seperate files:
split -l 1 --numeric-suffixes=1 --additional-suffix=.txt --suffix-length=6 to.parse ''

#A list was then made of all of these files
ls -1 *.txt > list.tsv

#Now we are ready to run the Rscript:
cat k2p.R

#print(k2p.R)

library(ape)
alignments = read.table("list.tsv", sep="\t")
colnames(alignments) = c("sp1_sp2")

#iterate over alignments list and estimate divergence
write.table(t(c( "spp", "length", "raw", "K80", "K81", "F84", "TN93")), "DNAdiv_estimates.csv", sep=",", row.names=F, col.names=F, append=F)
write.table(t(c("starting loop")), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=F)
for(f in 1:nrow(alignments)){
  # read in each data file
  data = read.table(paste(alignments$sp1_sp2[f]), sep=" ", header=F)
  colnames(data) = c("query_contig", "subject_scaffold", "query_seq", "subject_seq")
  # print summary statistics to stdout
  print(paste("alignment: ", alignments$sp1_sp2[f]))

  #prep aligned sequences
  s = strsplit(paste(data$subject_seq, "", collapse=""), "")
  q = strsplit(paste(data$query_seq, "", collapse=""), "")

  temp = as.DNAbin(c(s, q))
  write.table(paste("created DNAbin for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)

  #estimate divergences
  raw = K80 = K81 = F84 = TN93 = NULL
  raw = dist.dna(temp, model=c("raw"), variance = T)
  K80 = dist.dna(temp, model=c("K80"), variance = T)
  K81 = dist.dna(temp, model=c("K81"), variance = T)
  F84 = dist.dna(temp, model=c("F84"), variance = T)
  TN93 = dist.dna(temp, model=c("TN93"), variance = T)
  #cat(str(K80)); cat(str(K81)); cat(str(raw)); cat(str(F84)); cat(str(TN93))
  write.table(paste("Finished total calculations for", as.character(alignments$sp1_sp2[f])), "DNAdiv_watch.csv", sep=",", row.names=F, col.names=F, append=T)

  #save output
  write.table(t(c(as.character(alignments$sp1_sp2[f]), summary(temp)[1,1], raw, K80, K81, F84, TN93)), "DNAdiv_estimates.csv", sep=",", row.names=F, col.names=F, append=T)

  # run separately for all aligned sequences
  write.table(t(c("query_contig", "subject_scaffold","query_seq", "subject_seq", "raw", "K80", "K81", "F84", "TN93")), paste("DNAdiv_sequences_", as.character(alignments$sp1_sp2[f]), ".csv", sep = ""), sep=",", row.names=F, col.names=F, append=F)
  # run estimates for each row
}

#And Rscript was used to run the dist.dna function in the ape package
Rscript k2p.R

#Change the name of the output file for clarity:
mv DNAdiv_estimates.csv crov_stt.csv

#Print out and save other relevant information
awk '{print $1,$2,$3, $10, $11, $13, $14}' BLAST_cvir_scat_100kb.txt > cvir_scat.columns.csv

#download crov_stt* files to computer to generate plot(s) with ggplot2
>library(ggplot2)

a<-ggplot(data=cvir_scat, aes(x=qid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.0273, linetype=8,colour="blue",size=1)+ggtitle(" C. viridis \n S. catenatus")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(0,0.3))

summary(cvir_scat$K81)
#Min.  1st Qu.   Median     Mean  3rd Qu.     Max.
#0.008054 0.017502 0.020351 0.027314 0.024758 0.281485

ggsave(a,device = 'tiff',filename = "cvir_scat.tiff")

a<-ggplot(data=cvir_ste, aes(x=qid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.0189, linetype=8,colour="blue",size=1)+ggtitle(" C. viridis \n S. tergeminus edwardsii")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(0,0.3))

summary(cvir_ste$K81)
#Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
#0.00709 0.01532 0.01791 0.01839 0.02102 0.04255

ggsave(a,device = 'tiff',filename = "cvir_ste.tiff")

a<-ggplot(data=cvir_stt, aes(x=sid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.0189, linetype=8,colour="blue",size=1)+ggtitle(" C. viridis \n S. tergeminus tergeminus")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(0,0.3))

summary(cvir_stt$K81)
#Min.  1st Qu.   Median     Mean  3rd Qu.     Max.
#0.007093 0.015815 0.018280 0.018979 0.021379 0.129276

ggsave(a,device = 'tiff',filename = "cvir_stt.tiff")

a<-ggplot(data=scat_ste, aes(x=sid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.0079, linetype=8,colour="blue",size=1)+ggtitle(" S. catenatus \n S. tergeminus edwardsii")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(0,0.3))

summary(scat_ste$K81)
#Min.   1st Qu.    Median      Mean   3rd Qu.      Max.
#0.0007678 0.0057361 0.0074786 0.0079023 0.0096135 0.0320706

ggsave(a,device = 'tiff',filename = "scat_ste.tiff")

a<-ggplot(data=scat_stt, aes(x=sid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.0082, linetype=8,colour="blue",size=1)+ggtitle(" S. catenatus \n S. tergeminus tergeminus")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(0,0.3))

summary(scat_stt$K81)
#Min.   1st Qu.    Median      Mean   3rd Qu.      Max.
#0.0002042 0.0061326 0.0079573 0.0082840 0.0100663 0.0328956

ggsave(a,device = 'tiff',filename = "scat_stt.tiff")

a<-ggplot(data=stt_ste, aes(x=qid,y=K81))+geom_point(size=2,colour="black",position = 'jitter') +theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ geom_hline(yintercept = 0.00431, linetype=8,colour="blue",size=1)+ggtitle(" S. tergeminus tergeminus (subject) \n S. tergeminus edwardsii (query)")+ theme(plot.title = element_text(color="blue", size=14, face="bold.italic"))+theme(legend.position = "none",panel.grid = element_blank(),axis.title = element_blank(),panel.background = element_blank())+ylim(c(-0.01,0.3))+ theme(axis.title.x=element_blank(),axis.text.x=element_blank(),axis.ticks.x=element_blank())

#  Min.  1st Qu.   Median     Mean  3rd Qu.     Max.
#0.000000 0.001410 0.003392 0.004311 0.005563 0.228052

ggsave(a,device = 'tiff',filename = "A_ste_stt.tiff")


#Done
