###########################################################################
###									###
###	best kmer length estimation for single-k denovo assemblers	###
###									###
###	Given a set of reads, KmerGenie first computes the kmer		###
###	abundance histogram for many values of k. Then, for each	###
###	value of k, KmerGenie predicts the number of distinct genomic	###
###	kmers in the dataset and returns the kmer length which		###
###	maximizes this number.						###
###########################################################################

#!/bin/sh -l
#PBS -q fnrdewoody
#PBS -l nodes=1:ppn=20
#PBS -l walltime=336:00:00
#PBS -N kmergenie&jellyfish
#PBS -M bylsma@purdue.edu
#PBS -m abe

cd $PBS_O_WORKDIR
module purge
module use /apps/group/bioinfo/modules
module load kmergenie
module load anaconda
module load r
module load jellyfish

# calculate optimal k-mer

cd /scratch/snyder/b/bylsma/massasauga/stedwardsii/

kmergenie reads/edwardsiiPE_reads_filelist.txt -k 150 -l 20 -s 5 -t 20 \
-o assembly/abyss.denovo/stedwardsii.kmergenie \
&> assembly/abyss.denovo/stedwardsii.kmergenie.logfile.log

#Just create a file called "reads_file" then put all the *.fq file names into this file, each file name per line.
#Then use the command as suggested in the user manual.
# format:
# estimate genome size (for best kmer)
# best kmer = 100
#	#count number of kmers
#		#(m=k)
#		#(s=Genome size + genome*[1% illumina error rate]*[estimated coverage]*[number of expected kmers])
#		#(t=threads)
#	jellyfish count -m 21 -s 100M -t 10 -C reads.fasta
#	jellyfish -o histo.jf mer_counts.jf

cd /scratch/snyder/b/bylsma/massasauga/stedwardsii/

mkdir assembly/k100

jellyfish count -C -m 100 -s 3G -t 40 \
-o assembly/abyss.denovo/k100/jellyfish_edwardsii_07.25.2019.jf \
reads/edwardsiiPE_reads_filelist.txt \
&> assembly/abyss.denovo/k100/jellyfish_edwardsii_07.25.2019.log

jellyfish histo -o assembly/abyss.denovo/k100/jellyfish_edwardsii_07.25.2019_histo.jf \
assembly/abyss.denovo/k100/jellyfish_edwardsii_07.25.2019.jf

# END
