#!/bin/bash
#SBATCH --job-name=mito_ste
#SBATCH -A fnrfish
#SBATCH -t 14-00:00:00
#SBATCH -n 10
#SBATCH --mem=100G
#SBATCH -o mitobim.out
#SBATCH --mail-type=ALL

module purge
module load bioinfo
module load MITObim/1.8
module load mira/4.9.5
module load bioinfo
module load bwa
module load picard-tools
module load bedops
module load GATK/3.6.0
module load samtools
module load seqtk
export PATH=/home/bylsma/CoalQC/scripts/:$PATH
export coalpath=/home/bylsma/CoalQC/scripts
cd $SLURM_SUBMIT_DIR

coalqc map -g ../c.adamanteus.fa -f ../R1.fastq -r ../R2.fastq -p mapped_mt -n 10

samtools view -b -F 4 mapped_mt/mapped_mt.sort.bam > ./mapped_F_mt.bam

#Convert interleaved files over to fastq
samtools bam2fq ./mapped_F_mt.bam > mapped_mt.fastq

#modify headers for forward and paired reads
cat mapped_mt.fastq | grep '^@.*/1$' -A 3 --no-group-separator > mapped_r1.fastq
cat mapped_mt.fastq | grep '^@.*/2$' -A 3 --no-group-separator > mapped_r2.fastq

#Interleave mapped fastq paired-end reads
interleave-fastqgz-MITOBIM.py mapped_r1.fastq mapped_r2.fastq > ste_interleaved.fastq

# Downsample reads to reduce coverage and number of trash contigs
seqtk sample -s100 mapped_r1.fastq 5000 > mapped_r1_subset5k.fastq
seqtk sample -s100 mapped_r2.fastq 5000 > mapped_r2_subset5k.fastq
interleave-fastqgz-MITOBIM.py mapped_r1_subset5k.fastq mapped_r2_subset5k.fastq > ste_interleaved_subset5k.fastq
# Step 1:
mira manifest.conf
# Step 2:
MITObim.pl -start 1 -end 10 \
-sample A00218 -ref NC_041524.1 -readpool ste_interleaved_subset5k.fastq \
-maf initial-mapping-to-Crotalus-mt_assembly/initial-mapping-to-Crotalus-mt_d_results/initial-mapping-to-Crotalus-mt_out.maf \
--kbait 21 --paired \
&> log

#END
